female_prefix = [
    "ana",
    "ara",
    "bel",
    "dara",
    "elena",
    "ira",
    "kata",
    "lena",
    "mara",
    "nina",
    "oksana",
    "pela",
    "rada",
    "sara",
    "tana",
    "ula",
    "vala",
    "wera",
    "xena",
    "yara",
    "zara",
    "ada",
    "bela",
    "gala",
    "jana",
    "kira",
    "lana",
    "mila",
    "nata",
    "ola",
]

female_suffix = [
    "ala",
    "ara",
    "ela",
    "ina",
    "ira",
    "lina",
    "mila",
    "naya",
    "nya",
    "sana",
    "tina",
    "ya",
    "yana",
    "yara",
    "yla",
    "yra",
    "asha",
    "enka",
    "iska",
    "kina",
    "lena",
    "mira",
    "nika",
    "rina",
    "sya",
    "tina",
    "usha",
    "vina",
    "ysha",
    "za",
]

male_prefix = [
    "aleks",
    "and",
    "art",
    "bor",
    "den",
    "dmitr",
    "evgen",
    "fel",
    "genn",
    "grig",
    "ily",
    "ivan",
    "kir",
    "kon",
    "leon",
    "maks",
    "mikh",
    "nik",
    "oleg",
    "pavel",
    "petr",
    "roman",
    "serg",
    "stan",
    "tim",
    "vadim",
    "valer",
    "vict",
    "vlad",
    "yur",
]

male_suffix = [
    "an",
    "ar",
    "ev",
    "i",
    "ian",
    "in",
    "is",
    "iy",
    "k",
    "ko",
    "mi",
    "nic",
    "o",
    "omir",
    "or",
    "ov",
    "ri",
    "ski",
    "slav",
    "slov",
    "tar",
    "ti",
    "ton",
    "v",
    "vi",
    "vol",
    "y",
    "yev",
    "yin",
    "yush",
]

surname_prefix = [
    "ale",
    "an",
    "bor",
    "che",
    "dmi",
    "ef",
    "gav",
    "igor",
    "kap",
    "lar",
    "mikh",
    "nik",
    "ole",
    "pav",
    "rog",
    "serg",
    "tar",
    "vlad",
    "yev",
    "zhen",
    "zol",
    "ish",
    "kaz",
    "lev",
    "maks",
    "nov",
    "oleg",
    "pyot",
    "rud",
    "sash",
]

surname_suffix = [
    "ev",
    "in",
    "ov",
    "ski",
    "sky",
    "ko",
    "ov",
    "evich",
    "ovich",
    "yev",
    "yevich",
    "enko",
    "chuk",
    "ikh",
    "enko",
    "shin",
    "ayev",
    "nov",
    "yuk",
    "ukov",
    "yakin",
    "tsov",
    "kin",
    "kov",
    "nyuk",
    "tsy",
]

female_names = [
    "Ada",
    "Adałajda",
    "Adela",
    "Adelajda",
    "Adrianna",
    "Agata",
    "Agnieszka",
    "Agrypina",
    "Aldona",
    "Aleksandra",
    "Alena",
    "Alicja",
    "Amelia",
    "Anastazja",
    "Aniela",
    "Anna",
    "Antonina",
    "Apolonia",
    "Aurelia",
    "Barbara",
    "Bartłomieja",
    "Bazylika",
    "Berta",
    "Bianka",
    "Bogdana",
    "Bogna",
    "Bolesława",
    "Bożena",
    "Bronisława",
    "Cecylia",
    "Cecylka",
    "Cezaria",
    "Czesława",
    "Czyża",
    "Dagmara",
    "Dagmary",
    "Dalia",
    "Daniela",
    "Danuta",
    "Debora",
    "Diana",
    "Dobrawa",
    "Domicela",
    "Donata",
    "Dorota",
    "Dorotka",
    "Dusza",
    "Edmunda",
    "Edyta",
    "Edytki",
    "Ela",
    "Eleonora",
    "Eliza",
    "Elżbieta",
    "Emilia",
    "Emilka",
    "Emmy",
    "Estera",
    "Eugenia",
    "Ewa",
    "Ewelina",
    "Ezabella",
    "Felicja",
    "Franciszka",
    "Gabriela",
    "Gabriella",
    "Genowefa",
    "Gertruda",
    "Gisela",
    "Gizela",
    "Gloria",
    "Grażyna",
    "Halina",
    "Halinka",
    "Hanna",
    "Helena",
    "Helenka",
    "Helga",
    "Henrieta",
    "Honorata",
    "Ida",
    "Idalia",
    "Idzia",
    "Iga",
    "Ignacja",
    "Ika",
    "Ilona",
    "Inga",
    "Inka",
    "Innocenta",
    "Irena",
    "Irmina",
    "Iwa",
    "Iwona",
    "Iza",
    "Izabella",
    "Izolda",
    "Jadwiga",
    "Jaga",
    "Jagna",
    "Jagoda",
    "Janina",
    "Jarmiła",
    "Jasmina",
    "Jasna",
    "Joanna",
    "Jolanta",
    "Jolka",
    "Jowina",
    "Jowita",
    "Judyta",
    "Julia",
    "Julitta",
    "Julka",
    "Justa",
    "Justyna",
    "Juta",
    "Kalina",
    "Kamila",
    "Kanty",
    "Karina",
    "Karolina",
    "Kasandra",
    "Katarzyna",
    "Katarzynka",
    "Kazimiera",
    "Kinga",
    "Klaudia",
    "Klementyna",
    "Kleopatra",
    "Kordelia",
    "Kornelia",
    "Kosma",
    "Krysta",
    "Krystyna",
    "Krystynka",
    "Krzysztofa",
    "Ksawera",
    "Lidia",
    "Lidka",
    "Lili",
    "Liliana",
    "Liza",
    "Lora",
    "Ludmila",
    "Ludmiła",
    "Luiza",
    "Magda",
    "Magdalena",
    "Maja",
    "Malina",
    "Mandolina",
    "Marcelina",
    "Margarita",
    "Maria",
    "Mariam",
    "Marianna",
    "Marietta",
    "Marta",
    "Martka",
    "Martyna",
    "Marzanna",
    "Matylda",
    "Małgorzata",
    "Melania",
    "Milena",
    "Mira",
    "Mirella",
    "Mirka",
    "Mirosława",
    "Miła",
    "Monika",
    "Nadia",
    "Natalia",
    "Nikola",
    "Nikolina",
    "Nina",
    "Nora",
    "Oda",
    "Ola",
    "Olga",
    "Olimpia",
    "Olina",
    "Oliwia",
    "Olka",
    "Otylia",
    "Patrycja",
    "Paula",
    "Paulina",
    "Pelagia",
    "Pola",
    "Rachela",
    "Regina",
    "Renata",
    "Rita",
    "Roksana",
    "Roksanka",
    "Rozalia",
    "Rozalinda",
    "Róża",
    "Saba",
    "Sabina",
    "Sandra",
    "Sara",
    "Sebastiana",
    "Serafina",
    "Serapia",
    "Seweryna",
    "Sibilla",
    "Sonia",
    "Sophia",
    "Stanisława",
    "Stefania",
    "Stela",
    "Swietłana",
    "Sylwana",
    "Sylwia",
    "Taida",
    "Tamara",
    "Tatiana",
    "Teresa",
    "Tola",
    "Tosia",
    "Ula",
    "Urszula",
    "Walentyna",
    "Waleria",
    "Wanda",
    "Weronika",
    "Wiktoria",
    "Wilhelmina",
    "Wioleta",
    "Zdzisława",
    "Zenobia",
    "Zina",
    "Zofia",
    "Zuzanna",
]

male_names = [
    "Agaton",
    "Aleksandr",
    "Anatol",
    "Anatoli",
    "Andrei",
    "Anton",
    "Arkadi",
    "Arsen",
    "Bartolomej",
    "Benedikt",
    "Bogdan",
    "Bogomir",
    "Bogumil",
    "Boguslav",
    "Boleslav",
    "Boris",
    "Borislav",
    "Bozhidar",
    "Branimir",
    "Branislav",
    "Cyril",
    "Danko",
    "Dimitar",
    "Dimitri",
    "Dobromil",
    "Dobromir",
    "Dobroslav",
    "Dominik",
    "Dragan",
    "Dragomir",
    "Drazhan",
    "Dusan",
    "Edmund",
    "Eduard",
    "Emil",
    "Emilian",
    "Erazim",
    "Evdokim",
    "Evgeni",
    "Fedor",
    "Feofil",
    "Gavril",
    "Gedeon",
    "Georgi",
    "Gleb",
    "Goran",
    "Gregor",
    "Grigori",
    "Gustav",
    "Hristo",
    "Igor",
    "Ilia",
    "Iliya",
    "Ilyas",
    "Ivan",
    "Janko",
    "Jaromir",
    "Kamen",
    "Kazimir",
    "Kiril",
    "Konstantin",
    "Kostadin",
    "Kostya",
    "Kuzma",
    "Ladislav",
    "Lazar",
    "Leonid",
    "Lev",
    "Lubomir",
    "Lyubomir",
    "Maksim",
    "Marko",
    "Matej",
    "Matvey",
    "Mihail",
    "Mikhail",
    "Milan",
    "Miroslav",
    "Nestor",
    "Nikola",
    "Nikolai",
    "Nikolay",
    "Oleg",
    "Orest",
    "Panteley",
    "Pavel",
    "Petar",
    "Piotr",
    "Radimir",
    "Radomir",
    "Radoslav",
    "Radovan",
    "Rastislav",
    "Ratimir",
    "Ratko",
    "Robert",
    "Rodion",
    "Rodomil",
    "Rodoslav",
    "Roman",
    "Rostislav",
    "Ruslan",
    "Sasha",
    "Sava",
    "Saveliy",
    "Sergei",
    "Sergey",
    "Sokrat",
    "Stanimir",
    "Stanislav",
    "Stefan",
    "Svetoslav",
    "Svyatoslav",
    "Tadej",
    "Tihomir",
    "Timofei",
    "Timur",
    "Todor",
    "Valdemar",
    "Valentin",
    "Valeri",
    "Vasil",
    "Velimir",
    "Viktor",
    "Vladimir",
    "Vladislav",
    "Vlastimir",
    "Volodya",
    "Vsevolod",
    "Vukan",
    "Yakov",
    "Yan",
    "Yaromir",
    "Yaroslav",
    "Yasen",
    "Yulian",
    "Yuri",
    "Zahar",
    "Zbignev",
    "Zdravko",
    "Zhdan",
    "Zinoviy",
    "Zlatan",
    "Zlatko",
    "Zlatomir",
    "Zoran",
    "Zosim",
    "Zvenimir",
    "Zvonimir",
    "Zvonko",
    "Zygmunt",
]

surnames = [
    "Abramović",
    "Agapov",
    "Aleksandrov",
    "Alekseev",
    "Anastasov",
    "Andreev",
    "Anděl",
    "Antonović",
    "Babić",
    "Bogdanov",
    "Borisov",
    "Bosnić",
    "Bozhkov",
    "Bílý",
    "Cibulka",
    "Cvetković",
    "Denisov",
    "Dimitrov",
    "Dmitriev",
    "Dobrev",
    "Dobrovolny",
    "Dvořák",
    "Elias",
    "Emilov",
    "Evgeniev",
    "Evseev",
    "Fedorov",
    "Filipović",
    "Filippov",
    "Ganchev",
    "Gavrilov",
    "Gennadiev",
    "Georgiev",
    "Grigoriev",
    "Grujić",
    "Horák",
    "Hristov",
    "Hájek",
    "Ignatov",
    "Iliev",
    "Ilić",
    "Ilyin",
    "Ivanov",
    "Ivanović",
    "Janković",
    "Jirásek",
    "Jordanov",
    "Jovanović",
    "Kirillov",
    "Kirilov",
    "Kostov",
    "Kovačević",
    "Kováč",
    "Kozák",
    "Kuznetsov",
    "Lazarević",
    "Lazarov",
    "Lebedev",
    "Leonidov",
    "Luchev",
    "Lukić",
    "Maksimov",
    "Marek",
    "Marinov",
    "Marković",
    "Mihaylov",
    "Mikhailov",
    "Mládek",
    "Nikolaev",
    "Nikolayev",
    "Nikolić",
    "Nikolov",
    "Novák",
    "Němec",
    "Obradović",
    "Olegov",
    "Olegovich",
    "Olšák",
    "Pavlov",
    "Pavlović",
    "Pavlíček",
    "Petkov",
    "Petrov",
    "Petrović",
    "Radkov",
    "Radojičić",
    "Radoslavov",
    "Romanov",
    "Rostislavov",
    "Russo",
    "Růžička",
    "Sergeev",
    "Sergeyev",
    "Simeonov",
    "Sokolov",
    "Stefanov",
    "Stojanović",
    "Timofeev",
    "Todorov",
    "Tomić",
    "Tomášek",
    "Tůma",
    "Uhlíř",
    "Valentinov",
    "Vasiliev",
    "Vasiljević",
    "Veselý",
    "Viktorov",
    "Vladimirov",
    "Vlček",
    "Yakovlev",
    "Yordanov",
    "Yuryev",
    "Zahariev",
    "Zaharov",
    "Zahradník",
    "Zakharov",
    "Zima",
    "Černý",
    "Đorđević",
    "Ševčík",
]
