female_prefix = [
    "aða",
    "æl",
    "arn",
    "björn",
    "dís",
    "eið",
    "ey",
    "fríð",
    "gud",
    "gull",
    "gyð",
    "hild",
    "hjör",
    "ing",
    "líf",
    "run",
    "sif",
    "skjald",
    "skuld",
    "sól",
    "thor",
    "val",
    "víg",
    "ygg",
]

female_suffix = [
    "björg",
    "dóttir",
    "ey",
    "fey",
    "fríða",
    "gärd",
    "gyða",
    "hild",
    "hjör",
    "inga",
    "lína",
    "runa",
    "sigríð",
    "skjöld",
    "skuld",
    "sól",
    "thor",
    "vald",
    "ví",
    "vig",
    "ygg",
]

male_prefix = [
    "að",
    "al",
    "arn",
    "ask",
    "bað",
    "bjǫrn",
    "dǫrr",
    "eir",
    "ein",
    "fjǫr",
    "geir",
    "grim",
    "gunn",
    "hǫrð",
    "ing",
    "jarl",
    "kárr",
    "kol",
    "leifr",
    "mǫrk",
    "njal",
    "od",
    "ǫrn",
    "rauð",
    "skǫgr",
    "steinn",
    "tórr",
    "úlfr",
    "vald",
    "víð",
    "yng",
]

male_suffix = [
    "arr",
    "bjǫrn",
    "dall",
    "einarr",
    "fang",
    "geir",
    "grimr",
    "hǫrðr",
    "iarr",
    "jǫrn",
    "kell",
    "lárr",
    "mann",
    "njarð",
    "olfr",
    "ráð",
    "skell",
    "steinn",
    "thórr",
    "ulf",
    "valdr",
    "víðr",
    "yrn",
]

surname_prefix = [
    "aeg",
    "aer",
    "arn",
    "as",
    "baer",
    "ber",
    "bjorn",
    "daeg",
    "dagr",
    "ein",
    "eir",
    "ey",
    "freyr",
    "gar",
    "geir",
    "grim",
    "haeg",
    "haer",
    "haf",
    "hald",
    "har",
    "hjor",
    "kjaer",
    "leifr",
    "mund",
    "raed",
    "raeg",
    "ran",
    "saer",
    "sig",
    "skjold",
    "staf",
    "stein",
    "svein",
    "thaeg",
    "thor",
    "tor",
    "ulfr",
    "vaeg",
    "vaer",
    "vald",
    "veig",
    "ver",
    "vid",
    "vigr",
    "vind",
    "yng",
]

surname_suffix = [
    "ard",
    "bjorn",
    "brand",
    "dal",
    "dottir",
    "drifa",
    "drot",
    "eidr",
    "fast",
    "fjord",
    "flod",
    "frej",
    "gard",
    "gils",
    "haugr",
    "heim",
    "hildr",
    "holt",
    "ing",
    "jord",
    "kjold",
    "lind",
    "magn",
    "nord",
    "rafn",
    "rak",
    "rik",
    "sif",
    "skar",
    "son",
    "stein",
    "stir",
    "thor",
    "tor",
    "ulf",
    "vald",
    "vang",
    "ve",
    "vig",
    "vin",
    "vir",
    "vor",
    "yng",
    "yv",
]

female_names = [
    "Aesa",
    "Alfhildr",
    "Alruna",
    "Astridr",
    "Audhildr",
    "Bera",
    "Bergljot",
    "Bodil",
    "Brynhildr",
    "Dagny",
    "Eir",
    "Eiriksdottir",
    "Estrid",
    "Eydis",
    "Frida",
    "Gerda",
    "Gudrun",
    "Gunnhildr",
    "Gyda",
    "Hedvig",
    "Helga",
    "Herdis",
    "Hilde",
    "Hildr",
    "Idunn",
    "Ingeborg",
    "Ingrid",
    "Jofrid",
    "Kara",
    "Kari",
    "Kirsten",
    "Liv",
    "Maren",
    "Ragna",
    "Ragnhildr",
    "Ranveig",
    "Runa",
    "Saga",
    "Sif",
    "Signy",
    "Sigrid",
    "Sigrun",
    "Skadi",
    "Solveig",
    "Stikla",
    "Svanhildr",
    "Thora",
    "Thyra",
    "Torhildr",
    "Tove",
    "Unn",
    "Vigdis",
    "Yngvildr",
    "Yrsa",
]

male_names = [
    "Agnar",
    "Alfr",
    "Alof",
    "Ansgar",
    "Arnbjorn",
    "Arnbjörn",
    "Arngeir",
    "Arvid",
    "Asgeir",
    "Baldur",
    "Bard",
    "Bengt",
    "Birger",
    "Bjorn",
    "Björn",
    "Dag",
    "Dagfinn",
    "Dagfinnr",
    "Egil",
    "Einar",
    "Eindride",
    "Eirikr",
    "Erik",
    "Erling",
    "Eskil",
    "Finn",
    "Finnr",
    "Folke",
    "Frej",
    "Freyr",
    "Frode",
    "Geir",
    "Geirr",
    "Gormr",
    "Grím",
    "Gudmundr",
    "Gunnar",
    "Gunnbjorn",
    "Gustav",
    "Gyril",
    "Gísli",
    "Hakon",
    "Halfdan",
    "Halfdanr",
    "Halldór",
    "Hallvarðr",
    "Halvar",
    "Halvdan",
    "Harald",
    "Hartvig",
    "Hauk",
    "Haukr",
    "Heimdalr",
    "Helgi",
    "Hemming",
    "Hjalmar",
    "Hjálmar",
    "Höskuld",
    "Ingemar",
    "Ivar",
    "Jarl",
    "Jofrid",
    "Johan",
    "Jorund",
    "Jóhann",
    "Ketil",
    "Ketill",
    "Knut",
    "Konráð",
    "Kári",
    "Lasse",
    "Leif",
    "Leifr",
    "Ljót",
    "Magne",
    "Magnus",
    "Magnús",
    "Njord",
    "Njål",
    "Odd",
    "Oddgeir",
    "Oddr",
    "Ogmund",
    "Olaf",
    "Ormr",
    "Orvar",
    "Peder",
    "Ragnar",
    "Ragnarr",
    "Rane",
    "Rasmus",
    "Rolf",
    "Rögnir",
    "Rúni",
    "Sigbjorn",
    "Sigmundr",
    "Sigurd",
    "Sindri",
    "Stefan",
    "Steinar",
    "Styrbjörn",
    "Svante",
    "Sven",
    "Svend",
    "Teitur",
    "Teodor",
    "Thorbjorn",
    "Thore",
    "Thorfinn",
    "Torfi",
    "Torkel",
    "Torsten",
    "Tryggvi",
    "Tómas",
    "Ulf",
    "Ulrik",
    "Valdimarr",
    "Valr",
    "Verner",
    "Vidar",
    "Viggo",
    "Viglaf",
    "Vésteinn",
    "Víga-Hrappr",
    "Víkingr",
    "Yngvar",
    "Yngvarr",
    "Yngve",
    "Ärnljot",
    "Åke",
    "Åsgeir",
    "Åsleif",
    "Ívarr",
    "Óðinn",
    "Örjan",
    "Úlfr",
    "Þorfinnr",
    "Þorgrímr",
    "Þorsteinn",
    "Þrymr",
    "Þrándr",
    "Þrœndr",
    "Þórgeirr",
    "Þórketill",
    "Þórsteinn",
    "Þórvaldr",
    "Þórðr",
]

surnames = [
    "Aesirsson",
    "Agni",
    "Alderson",
    "Arnesson",
    "Arngrim",
    "Asgeir",
    "Asgeirsson",
    "Askell",
    "Askellson",
    "Baldr",
    "Baldrsson",
    "Bjorn",
    "Bjornsson",
    "Egil",
    "Egilsson",
    "Einar",
    "Einarsdottir",
    "Eirik",
    "Eiriksson",
    "Finn",
    "Finnsson",
    "Fjeldsted",
    "Freyrsson",
    "Frostisson",
    "Gudmund",
    "Gudmundsson",
    "Gunnar",
    "Gunnarsson",
    "Halfdan",
    "Halfdansson",
    "Halvar",
    "Halvarsson",
    "Harald",
    "Haraldsson",
    "Havard",
    "Havardsson",
    "Helgason",
    "Helgi",
    "Herjolf",
    "Herjolfsson",
    "Hjalmarr",
    "Hjalmarsdottir",
    "Holger",
    "Holgersson",
    "Hrolf",
    "Hrolfsson",
    "Ingebrigtsdottir",
    "Ivar",
    "Ivarsson",
    "Jarl",
    "Jarlsson",
    "Jokul",
    "Jokulsson",
    "Ketil",
    "Ketilsson",
    "Kolbein",
    "Kolbeinsson",
    "Leif",
    "Leifsdottir",
    "Loki",
    "Lokisson",
    "Magnus",
    "Magnusson",
    "Njord",
    "Njordsson",
    "Odin",
    "Odinson",
    "Olaf",
    "Olafsdottir",
    "Olavsson",
    "Oskar",
    "Oskarsson",
    "Ragnar",
    "Ragnarsson",
    "Rolf",
    "Rolfsson",
    "Sigmund",
    "Sigmundsson",
    "Sigurd",
    "Sigurdsson",
    "Sjurs",
    "Sjursdottir",
    "Skarphedin",
    "Skarphedinsson",
    "Skjold",
    "Skjoldsson",
    "Snorresson",
    "Snorri",
    "Sven",
    "Svennson",
    "Thorbjorn",
    "Thorbjornsson",
    "Thorfinn",
    "Thorfinnsson",
    "Torvald",
    "Torvaldsson",
    "Ulf",
    "Ulfsson",
    "Valdimar",
    "Valdimarsson",
    "Vidar",
    "Vidarsson",
    "Vigfus",
    "Vigfusson",
    "Yngvar",
    "Yngvarsson",
    "Yngve",
    "Yngvesdottir",
    "Yngvesson",
]
