female_prefix = [
    "ber",
    "bri",
    "cla",
    "cor",
    "dal",
    "dor",
    "el",
    "fro",
    "gol",
    "har",
    "hil",
    "lav",
    "lil",
    "lo",
    "mar",
    "mel",
    "nar",
    "nor",
    "ol",
    "per",
    "pip",
    "ro",
    "sam",
    "san",
    "syl",
    "tas",
    "wil",
]

female_suffix = [
    "a",
    "adoc",
    "ald",
    "bella",
    "belle",
    "dora",
    "ella",
    "elle",
    "freda",
    "gwen",
    "la",
    "lea",
    "lina",
    "lla",
    "lotta",
    "ma",
    "mia",
    "mina",
    "mira",
    "na",
    "nelle",
    "nna",
    "ra",
    "ri",
    "ria",
    "rie",
    "rina",
    "sa",
    "sella",
    "sie",
    "sy",
    "ta",
    "tina",
    "wyn",
]

male_prefix = [
    "albo",
    "bal",
    "bil",
    "bran",
    "con",
    "dodo",
    "ever",
    "fal",
    "fer",
    "fin",
    "gaf",
    "gim",
    "gol",
    "ham",
    "hob",
    "las",
    "leo",
    "lim",
    "lobo",
    "mar",
    "milo",
    "mung",
    "nico",
    "odo",
    "olbo",
    "pal",
    "per",
    "pim",
    "pip",
    "rolo",
    "ruf",
    "sam",
    "silbo",
    "tob",
    "ugo",
    "vigo",
    "wigo",
    "wim",
    "wise",
    "wolbo",
]

male_suffix = [
    "bo",
    "bri",
    "do",
    "dro",
    "fast",
    "fer",
    "gar",
    "go",
    "grin",
    "hard",
    "lo",
    "man",
    "mo",
    "nac",
    "nard",
    "nibo",
    "no",
    "per",
    "pin",
    "po",
    "ric",
    "rim",
    "ro",
    "san",
    "sim",
    "to",
    "wise",
]

surname_prefix = [
    "bagg",
    "bran",
    "bur",
    "cra",
    "cud",
    "good",
    "green",
    "hard",
    "hay",
    "hill",
    "le",
    "long",
    "merry",
    "oak",
    "old",
    "pere",
    "pip",
    "proud",
    "sack",
    "small",
    "tall",
    "took",
    "toss",
    "under",
    "whit",
]

surname_suffix = [
    "bottom",
    "buckle",
    "burr",
    "by",
    "digger",
    "foot",
    "girdle",
    "hair",
    "hobb",
    "ins",
    "kins",
    "leaf",
    "man",
    "over",
    "pint",
    "root",
    "shire",
    "thistle",
    "top",
    "wag",
    "ward",
    "wheat",
    "wort",
    "worthy",
]

female_names = [
    "Aelia",
    "Aemilia",
    "Alba",
    "Alira",
    "Amarylle",
    "Andrella",
    "Antonia",
    "Anysa",
    "Aquila",
    "Arula",
    "Augusta",
    "Aurelia",
    "Aurelius",
    "Aurora",
    "Avonelle",
    "Bellona",
    "Blossom",
    "Briella",
    "Caecilia",
    "Caelia",
    "Calinda",
    "Camilla",
    "Cassia",
    "Cecilia",
    "Celandra",
    "Celinda",
    "Ceridwen",
    "Cheribelle",
    "Clementia",
    "Cora",
    "Coralia",
    "Corisande",
    "Cornelia",
    "Daisy",
    "Dandelea",
    "Dellanna",
    "Diamanda",
    "Diana",
    "Dinella",
    "Domitia",
    "Dorinda",
    "Drusilla",
    "Eirlys",
    "Elara",
    "Elfinia",
    "Elora",
    "Elowyn",
    "Ember",
    "Endellion",
    "Epona",
    "Estella",
    "Fabiola",
    "Faeryn",
    "Faustina",
    "Faylinn",
    "Fenella",
    "Fiametta",
    "Flavia",
    "Fleur",
    "Floriana",
    "Fortuna",
    "Gemma",
    "Goldie",
    "Harmony",
    "Hazel",
    "Honeysuckle",
    "Idony",
    "Irisa",
    "Isolde",
    "Ivy",
    "Jewel",
    "Julia",
    "Justina",
    "Kerensa",
    "Laurentia",
    "Lavender",
    "Lavinia",
    "Leilani",
    "Lilias",
    "Livia",
    "Lorelei",
    "Lucilla",
    "Lucretia",
    "Lumina",
    "Lyric",
    "Maebry",
    "Marcella",
    "Marcia",
    "Marigold",
    "Marina",
    "Maxima",
    "Melantha",
    "Merryn",
    "Mila",
    "Mirabelle",
    "Misty",
    "Morgana",
    "Nerissa",
    "Nessa",
    "Nimue",
    "Octavia",
    "Olivine",
    "Opaline",
    "Orchid",
    "Oriana",
    "Paulina",
    "Peony",
    "Periwinkle",
    "Petal",
    "Petronia",
    "Pippin",
    "Poppy",
    "Portia",
    "Prima",
    "Primrose",
    "Quincy",
    "Rosalind",
    "Rowan",
    "Sabina",
    "Sabrina",
    "Saffron",
    "Samantha",
    "Sapphire",
    "Secundia",
    "Septima",
    "Seraphina",
    "Serena",
    "Shaylee",
    "Silvana",
    "Sorrel",
    "Stella",
    "Sylvia",
    "Tansy",
    "Tatiana",
    "Tertulla",
    "Tessera",
    "Thalia",
    "Titania",
    "Trillium",
    "Twyla",
    "Valentina",
    "Valeria",
    "Velia",
    "Verina",
    "Vesper",
    "Vibia",
    "Victoria",
    "Violetta",
    "Vita",
    "Willa",
    "Wisteria",
    "Yara",
    "Zephyrine",
    "Zinnia",
    "Zoe",
]

male_names = [
    "Adalman",
    "Aldern",
    "Alric",
    "Arro",
    "Balwin",
    "Barmund",
    "Beldon",
    "Bellis",
    "Beren",
    "Bifur",
    "Bolbo",
    "Bolger",
    "Brumley",
    "Bungo",
    "Calaman",
    "Carrot",
    "Cedric",
    "Cotton",
    "Dalman",
    "Dandy",
    "Deagol",
    "Doderic",
    "Donnegan",
    "Drogo",
    "Dudo",
    "Dundoc",
    "Dunny",
    "Elmer",
    "Elrond",
    "Elwis",
    "Falco",
    "Fastolph",
    "Filibert",
    "Fosco",
    "Frodo",
    "Gaffer",
    "Galahad",
    "Gerontius",
    "Gilly",
    "Ginger",
    "Gord",
    "Griffo",
    "Halfred",
    "Halson",
    "Hamfast",
    "Hamson",
    "Happylegs",
    "Harfoot",
    "Hending",
    "Hob",
    "Hobson",
    "Holfast",
    "Holman",
    "Hornblower",
    "Ingle",
    "Isembard",
    "Jago",
    "Kithran",
    "Largo",
    "Lobelia",
    "Lotho",
    "Madoc",
    "Marmaduke",
    "Masterful",
    "Milo",
    "Minto",
    "Mungo",
    "Nibs",
    "Nob",
    "Odo",
    "Olo",
    "Otho",
    "Paladin",
    "Pearlman",
    "Peregrin",
    "Pervinca",
    "Podo",
    "Posco",
    "Proudfoot",
    "Reginard",
    "Robin",
    "Roderic",
    "Roper",
    "Ruddy",
    "Rufus",
    "Samwise",
    "Sancho",
    "Saradoc",
    "Sigismond",
    "Togo",
    "Tolman",
    "Tom",
    "Tubbo",
    "Tulip",
    "Wilcome",
    "Wilibald",
    "Wilwarin",
    "Wiseacre",
    "Wort",
    "Wylis",
    "Yapper",
    "Yazoo",
    "Yogo",
    "Yule",
    "Yves",
    "Zam",
    "Zeff",
    "Zinn",
    "Zook",
]

surnames = [
    "Amberstone",
    "Applebrook",
    "Applegrove",
    "Auburnleaf",
    "Badgerhill",
    "Barleyfoot",
    "Berrybottom",
    "Birchwood",
    "Bluebell",
    "Bottlehill",
    "Bramblebush",
    "Brightmeadow",
    "Bumbleberry",
    "Burrystone",
    "Buttercup",
    "Candlewick",
    "Chestnut",
    "Cinderfoot",
    "Cobblehill",
    "Copperfield",
    "Copperknob",
    "Crickhollow",
    "Dandelion",
    "Dewberry",
    "Dewdrop",
    "Dillyhill",
    "Driftwood",
    "Eveningshade",
    "Fallowfield",
    "Feathergale",
    "Fernbrook",
    "Fernshadow",
    "Firelight",
    "Frostwhisper",
    "Gingerroot",
    "Goldberry",
    "Goldenleaf",
    "Gooseberry",
    "Gorseblossom",
    "Grasshopper",
    "Greenbottle",
    "Harvestmoon",
    "Hazelnut",
    "Heathertoes",
    "Hedgegrove",
    "Hobblefoot",
    "Hobbleknee",
    "Hollyberry",
    "Hollywhistle",
    "Honeydew",
    "Honeythorn",
    "Ironbeard",
    "Jasmine",
    "Jingletoe",
    "Kettlewhistle",
    "Larkspur",
    "Lavender",
    "Leafspring",
    "Lilybrook",
    "Littleberry",
    "Meadowsweet",
    "Merryman",
    "Milkweed",
    "Mistyspring",
    "Morningdew",
    "Mossleaf",
    "Mossybrook",
    "Mumblefoot",
    "Nightrunner",
    "Nimblefingers",
    "Nutmeg",
    "Oakendale",
    "Oakentoe",
    "Peachblossom",
    "Pebblebrook",
    "Pickleberry",
    "Picklefoot",
    "Potterspring",
    "Primrose",
    "Puddlefoot",
    "Pumpkinpatch",
    "Quicksilver",
    "Quietstream",
    "Radishbottom",
    "Redcheek",
    "Ripplebrook",
    "Riverstone",
    "Roosterfoot",
    "Rosedale",
    "Rosepetal",
    "Sageleaf",
    "Sandybanks",
    "Shadetree",
    "Shepherd",
    "Shimmerleaf",
    "Shortstocking",
    "Silverbell",
    "Silverleaf",
    "Skiprock",
    "Sleepyeyes",
    "Snickerdoodle",
    "Snugglebottom",
    "Songbird",
    "Sparkleberry",
    "Spiderwick",
    "Spindlewick",
    "Springdale",
    "Squirrelwhisker",
    "Starflower",
    "Starrynight",
    "Stoutfoot",
    "Strawberry",
    "Sunbeam",
    "Sweetwater",
    "Talltree",
    "Tanglethorn",
    "Tawnyberry",
    "Thistlebrook",
    "Thistletop",
    "Tinderwick",
    "Tinypocket",
    "Treetop",
    "Tricklebrook",
    "Tumblestone",
    "Tumbleweed",
    "Twilight",
    "Twinkletoes",
    "Wagglebottom",
    "Weedwhistle",
    "Wellington",
    "Wheatgrass",
    "Whisperingwind",
    "Whisperwind",
    "Wildflower",
    "Wildfoot",
    "Willowbrook",
    "Willowhollow",
    "Woodchuck",
    "Woodruff",
    "Woolysocks",
    "Yarrowroot",
    "Yewshade",
    "Zephyrdale",
    "Zinnia",
]
