male_prefix = [
    "aer",
    "ald",
    "an",
    "ar",
    "bar",
    "bor",
    "cal",
    "dal",
    "dan",
    "dur",
    "ed",
    "eld",
    "er",
    "fal",
    "fin",
    "gal",
    "gan",
    "gar",
    "had",
    "hal",
    "ian",
    "in",
    "kar",
    "kor",
    "lanc",
    "mar",
    "mer",
    "nor",
    "or",
    "rad",
    "ran",
    "ron",
    "sar",
    "sol",
    "tan",
    "thor",
    "tor",
    "ul",
    "val",
    "van",
    "vor",
    "wal",
    "war",
    "yor",
    "zar",
]

male_suffix = [
    "ald",
    "an",
    "ar",
    "ard",
    "bar",
    "dan",
    "dor",
    "dred",
    "dur",
    "fin",
    "gald",
    "gan",
    "gar",
    "hard",
    "horn",
    "ian",
    "ion",
    "lan",
    "mir",
    "nard",
    "or",
    "rad",
    "ran",
    "ric",
    "rin",
    "ron",
    "thor",
    "thorn",
    "und",
    "val",
    "var",
    "ward",
    "win",
    "wood",
    "wyn",
    "yar",
]

female_prefix = [
    "ad",
    "al",
    "an",
    "ar",
    "bel",
    "ca",
    "cel",
    "da",
    "di",
    "el",
    "en",
    "fa",
    "fay",
    "gal",
    "gi",
    "ha",
    "hel",
    "il",
    "in",
    "ja",
    "kel",
    "la",
    "le",
    "ma",
    "mi",
    "na",
    "ni",
    "ol",
    "pe",
    "qui",
    "ra",
    "re",
    "sa",
    "se",
    "ta",
    "thi",
    "va",
    "ve",
    "wil",
    "ya",
    "ze",
]

female_suffix = [
    "a",
    "ana",
    "ara",
    "beth",
    "cia",
    "da",
    "dea",
    "elle",
    "fa",
    "ga",
    "hilda",
    "ia",
    "iana",
    "ida",
    "ira",
    "la",
    "lia",
    "lina",
    "ma",
    "mia",
    "na",
    "nelle",
    "nia",
    "ra",
    "ria",
    "sa",
    "sia",
    "ta",
    "thea",
    "thia",
    "va",
    "via",
    "ya",
]

surname_prefix = [
    "ald",
    "arn",
    "bar",
    "ber",
    "brand",
    "carr",
    "cor",
    "dun",
    "eag",
    "eld",
    "fair",
    "gar",
    "gold",
    "han",
    "haw",
    "helm",
    "kings",
    "long",
    "oak",
    "rav",
    "red",
    "river",
    "rock",
    "silver",
    "stone",
    "thorn",
    "west",
    "white",
    "wind",
    "wynd",
    "yar",
    "zel",
    "al",
    "an",
    "ark",
    "ash",
    "ba",
    "bor",
    "be",
    "bel",
    "car",
    "cas",
    "cor",
    "dar",
    "de",
    "del",
    "di",
    "dor",
    "el",
    "er",
    "fal",
]

surname_suffix = [
    "bourne",
    "bridge",
    "brook",
    "castle",
    "field",
    "ford",
    "ham",
    "hurst",
    "lake",
    "ley",
    "mead",
    "mill",
    "shire",
    "stead",
    "stone",
    "ton",
    "view",
    "wall",
    "ward",
    "water",
    "well",
    "wick",
    "worth",
    "bay",
    "crest",
    "croft",
    "dale",
    "gate",
    "glen",
    "haven",
    "hill",
    "holme",
    "isle",
    "keep",
    "mere",
    "moor",
    "peak",
    "pool",
    "reach",
    "rise",
    "shade",
    "slope",
    "thorpe",
    "vale",
    "village",
    "weir",
    "wood",
    "yard",
    "zeal",
]

female_names = [
    "Adelaine",
    "Aeliana",
    "Aella",
    "Aeris",
    "Alandra",
    "Aldith",
    "Amara",
    "Amra",
    "Andralyn",
    "Anwyn",
    "Aquila",
    "Araluen",
    "Aravia",
    "Aria",
    "Ariantha",
    "Ariella",
    "Asteria",
    "Astrid",
    "Aurelia",
    "Aveth",
    "Beleth",
    "Belisara",
    "Brynhild",
    "Calanthe",
    "Calithra",
    "Calliope",
    "Carys",
    "Cassia",
    "Celandine",
    "Celestia",
    "Cerelia",
    "Coralie",
    "Corinna",
    "Cressida",
    "Daela",
    "Damaris",
    "Darielle",
    "Delmira",
    "Eirini",
    "Eirlys",
    "Elara",
    "Elariel",
    "Elira",
    "Elowen",
    "Elysande",
    "Elysia",
    "Emeldis",
    "Evangeline",
    "Faela",
    "Faralia",
    "Felina",
    "Fenella",
    "Fiorella",
    "Galatea",
    "Galitha",
    "Gwenara",
    "Gwyneira",
    "Havilah",
    "Helia",
    "Heliana",
    "Idony",
    "Idranel",
    "Iliana",
    "Ilmira",
    "Imralda",
    "Isabeau",
    "Ismira",
    "Isolde",
    "Jesmina",
    "Jocasta",
    "Junia",
    "Kaelynn",
    "Kalina",
    "Kalypso",
    "Kerensa",
    "Keridwen",
    "Laelia",
    "Larissa",
    "Leandra",
    "Leliana",
    "Lilith",
    "Lorelei",
    "Lorilda",
    "Lyra",
    "Maelis",
    "Maelisande",
    "Maelora",
    "Marella",
    "Maren",
    "Marigold",
    "Mavria",
    "Melantha",
    "Melia",
    "Melisande",
    "Melora",
    "Mirith",
    "Nephele",
    "Nerina",
    "Nerissa",
    "Nimiane",
    "Nyx",
    "Ophelia",
    "Oriana",
    "Oriella",
    "Perenelle",
    "Persephone",
    "Phaedra",
    "Quelira",
    "Ravenna",
    "Ravina",
    "Rhea",
    "Rhiana",
    "Rhoslyn",
    "Rhoswen",
    "Sapphira",
    "Sarilda",
    "Selara",
    "Selena",
    "Selene",
    "Seraphina",
    "Seraphine",
    "Shalara",
    "Talitha",
    "Tallis",
    "Tamsin",
    "Thais",
    "Thalara",
    "Thalia",
    "Thamara",
    "Valencia",
    "Valeria",
    "Valoria",
    "Vesmira",
    "Vespera",
    "Violetta",
    "Xanthe",
    "Yarilda",
    "Ysabeau",
    "Zara",
    "Zephyra",
    "Zephyrine",
    "Zinnia",
    "Zirel",
]

male_names = [
    "Alaric",
    "Alberic",
    "Alden",
    "Aldon",
    "Aldric",
    "Alric",
    "Alwin",
    "Arland",
    "Armand",
    "Armin",
    "Arnold",
    "Arnor",
    "Arnulf",
    "Balder",
    "Baldric",
    "Balric",
    "Balrik",
    "Baradan",
    "Bard",
    "Bardulf",
    "Baron",
    "Beldor",
    "Bertram",
    "Berwin",
    "Borin",
    "Boromir",
    "Brandar",
    "Bromir",
    "Cadmus",
    "Caldor",
    "Calwin",
    "Caradoc",
    "Caranthir",
    "Caspian",
    "Cedric",
    "Colman",
    "Corbin",
    "Cormac",
    "Corwin",
    "Dagmar",
    "Dagobert",
    "Damrod",
    "Darius",
    "Delwin",
    "Derwin",
    "Dorin",
    "Dunstan",
    "Eadric",
    "Eadwin",
    "Edgar",
    "Edric",
    "Edwin",
    "Eldric",
    "Elric",
    "Elrond",
    "Elwin",
    "Emeric",
    "Emmerich",
    "Emrick",
    "Emrys",
    "Erland",
    "Falcon",
    "Faldor",
    "Faramir",
    "Faramond",
    "Fergus",
    "Finarfin",
    "Frederic",
    "Frithwald",
    "Garrick",
    "Gawain",
    "Gellert",
    "Gerwin",
    "Gil-galad",
    "Gilbert",
    "Gildor",
    "Gorbad",
    "Gorlim",
    "Grimbold",
    "Grimric",
    "Grimwald",
    "Hadrian",
    "Hadric",
    "Hadwin",
    "Haldor",
    "Halric",
    "Hammond",
    "Hamric",
    "Harmond",
    "Harrow",
    "Helmund",
    "Helwin",
    "Hermund",
    "Hilbert",
    "Holman",
    "Ingmar",
    "Ingold",
    "Ingolf",
    "Isengar",
    "Isengrim",
    "Isenwald",
    "Isildur",
    "Jareth",
    "Jarlath",
    "Jarngrim",
    "Kaelan",
    "Kelvin",
    "Kendric",
    "Kendrick",
    "Kormac",
    "Korwin",
    "Lander",
    "Landon",
    "Leofric",
    "Leofwin",
    "Leomund",
    "Letholdus",
    "Lorand",
    "Lorcan",
    "Maldon",
    "Maldred",
    "Maldric",
    "Marwin",
    "Meriadoc",
    "Merrick",
    "Merry",
    "Mirbrand",
    "Mirik",
    "Miron",
    "Nevron",
    "Norbert",
    "Norwin",
    "Osgar",
    "Osmund",
    "Osric",
    "Oswald",
    "Oswin",
    "Othmar",
    "Radagast",
    "Radulf",
    "Ragnor",
    "Randulf",
    "Reginald",
    "Rexmond",
    "Rexmund",
    "Roderic",
    "Roderick",
    "Rodrick",
    "Rohirrim",
    "Roland",
    "Romar",
    "Samwell",
    "Samwise",
    "Saradoc",
    "Saruman",
    "Sigmar",
    "Sigurd",
    "Silmaril",
    "Sorin",
    "Talbot",
    "Talwin",
    "Targon",
    "Tarmon",
    "Tarmond",
    "Tarwin",
    "Thedric",
    "Theobald",
    "Theodoric",
    "Thorin",
    "Thorondor",
    "Tobias",
    "Torald",
    "Torwin",
    "Uldred",
    "Uldric",
    "Ulric",
    "Valandil",
    "Valdan",
    "Valdric",
    "Walden",
    "Walder",
    "Waldon",
    "Waldric",
    "Wilfred",
    "Wilhelm",
    "Willard",
    "Yoric",
    "Yorick",
    "Yorin",
    "Zander",
    "Zephram",
    "Zephyr",
    "Zephyrus",
]

surnames = [
    "of Angmar",
    "of Annúminas",
    "of Anor",
    "of Barad-dûr",
    "of Belegost",
    "of Bree",
    "of Carn Dûm",
    "of Dale",
    "of Dol Amroth",
    "of Dol Guldur",
    "of Dorwinion",
    "of Dunland",
    "of Edoras",
    "of Emyn Muil",
    "of Enedwaith",
    "of Erebor",
    "of Eregion",
    "of Esgaroth",
    "of Fangorn",
    "of Far Harad",
    "of Forlindon",
    "of Fornost",
    "of Forochel",
    "of Gondor",
    "of Gundabad",
    "of Harad",
    "of Harlindon",
    "of Harondor",
    "of Helm's Deep",
    "of Isengard",
    "of Ithilien",
    "of Khand",
    "of Lorien",
    "of Lothlórien",
    "of Minas Tirith",
    "of Mirkwood",
    "of Mithlond",
    "of Moria",
    "of Mount Gundabad",
    "of Nargothrond",
    "of Near Harad",
    "of Orthanc",
    "of Osgiliath",
    "of Rhovanion",
    "of Rhûn",
    "of Rivendell",
    "of Rohan",
    "of Thranduil's Halls",
    "of Umbar",
    "of Withered Heath",
    "of the Grey Havens",
    "of the Shire",
]
