female_prefix = [
    "agá",
    "aléx",
    "amphí",
    "aná",
    "arí",
    "athén",
    "démé",
    "élektr",
    "eurydí",
    "euthén",
    "galát",
    "harmón",
    "hébé",
    "hér",
    "kalí",
    "kleió",
    "kyprí",
    "lét",
    "méliss",
    "nér",
    "orestí",
    "pandór",
    "penél",
    "perí",
    "philómél",
    "pó",
    "thál",
    "théod",
    "xén",
]

female_suffix = [
    "a",
    "anthe",
    "dóra",
    "eia",
    "éne",
    "essa",
    "ia",
    "idóra",
    "ika",
    "inia",
    "ipé",
    "ithéa",
    "íne",
    "ita",
    "oé",
    "óra",
    "otea",
    "óti",
    "oula",
    "phén",
    "phíne",
    "phrón",
    "séa",
    "théa",
    "théne",
    "tía",
    "tra",
    "tía",
    "ydia",
]

male_prefix = [
    "aeg",
    "aer",
    "alex",
    "amph",
    "an",
    "anat",
    "and",
    "ant",
    "arch",
    "arist",
    "astr",
    "calli",
    "chr",
    "chrys",
    "cle",
    "cyr",
    "dam",
    "dem",
    "dion",
    "eir",
    "eugen",
    "euph",
    "her",
    "herm",
    "hip",
    "hipp",
    "kal",
    "klei",
    "leon",
    "lys",
    "megas",
    "myr",
    "neo",
    "nik",
    "olym",
    "pan",
    "per",
    "phil",
    "pho",
    "pol",
    "pyth",
    "soph",
    "theo",
    "theod",
    "xan",
    "xen",
    "zen",
]

male_suffix = [
    "ades",
    "ander",
    "archos",
    "as",
    "asios",
    "ax",
    "axos",
    "eides",
    "enios",
    "eochos",
    "eokles",
    "eon",
    "eris",
    "es",
    "ias",
    "ides",
    "ikles",
    "ion",
    "ios",
    "is",
    "kleis",
    "kles",
    "kriti",
    "lon",
    "lykos",
    "medes",
    "mon",
    "mos",
    "on",
    "or",
    "oris",
    "os",
    "otes",
    "otis",
    "ox",
    "oxenos",
    "oxis",
    "pheles",
    "phoros",
    "ptolemeos",
    "rakles",
    "ros",
    "ruthios",
    "sthenes",
    "stratos",
    "teles",
    "tides",
    "tor",
    "us",
    "xander",
    "xandros",
    "xenos",
    "xion",
    "xiphos",
    "ylos",
    "zenos",
]

surname_prefix = [
    "ae",
    "al",
    "an",
    "ap",
    "ar",
    "as",
    "ch",
    "di",
    "el",
    "en",
    "ep",
    "eu",
    "gl",
    "hy",
    "id",
    "is",
    "ka",
    "kr",
    "ly",
    "ma",
    "ne",
    "ny",
    "ol",
    "op",
    "or",
    "pe",
    "ph",
    "pl",
    "py",
    "rh",
    "sy",
    "th",
    "ti",
    "xy",
    "ze",
    "zo",
]

surname_suffix = [
    "dakis",
    "doros",
    "kis",
    "kides",
    "kis",
    "kos",
    "lidis",
    "los",
    "machos",
    "mides",
    "mos",
    "nadis",
    "nidis",
    "nomos",
    "padis",
    "pidis",
    "poulos",
    "reios",
    "ridis",
    "rinos",
    "rolos",
    "sidis",
    "sis",
    "skis",
    "solis",
    "sos",
    "tos",
    "tridis",
    "xidis",
    "zos",
]

female_names = [
    "Acacia",
    "Aella",
    "Agape",
    "Agatha",
    "Aglaia",
    "Aithra",
    "Alcestis",
    "Alcyone",
    "Alethea",
    "Alexandra",
    "Alexandria",
    "Althaia",
    "Althea",
    "Amalthea",
    "Amara",
    "Amarantha",
    "Amarillis",
    "Amphitrite",
    "Anais",
    "Anastasia",
    "Anatolia",
    "Andromache",
    "Andromeda",
    "Angeliki",
    "Anthea",
    "Antigone",
    "Aphrodite",
    "Apollonia",
    "Arete",
    "Ariadne",
    "Arista",
    "Artemis",
    "Aspasia",
    "Aster",
    "Asteria",
    "Astraea",
    "Astrid",
    "Atalanta",
    "Athena",
    "Aurelia",
    "Calantha",
    "Calliope",
    "Callista",
    "Calypso",
    "Cassandra",
    "Cassia",
    "Chloe",
    "Circe",
    "Cleopatra",
    "Clio",
    "Corinna",
    "Coronis",
    "Cybele",
    "Damaris",
    "Danae",
    "Daphne",
    "Daphnis",
    "Daria",
    "Delia",
    "Demeter",
    "Demetra",
    "Despina",
    "Despoina",
    "Diana",
    "Diantha",
    "Dido",
    "Dione",
    "Dorothea",
    "Eirene",
    "Elara",
    "Eleanor",
    "Elektra",
    "Elena",
    "Elene",
    "Eleni",
    "Elpis",
    "Elysia",
    "Elysse",
    "Eos",
    "Ephigenia",
    "Eudora",
    "Eugenia",
    "Eunice",
    "Euphemia",
    "Eurydice",
    "Evadne",
    "Evangelia",
    "Evanthe",
    "Faidra",
    "Faye",
    "Gaia",
    "Galatea",
    "Galene",
    "Halia",
    "Hecuba",
    "Helen",
    "Helena",
    "Helia",
    "Hera",
    "Hermia",
    "Hermione",
    "Hero",
    "Idalia",
    "Ifigeneia",
    "Iolanthe",
    "Ione",
    "Iphigenia",
    "Irene",
    "Iris",
    "Isabella",
    "Isadora",
    "Isidora",
    "Jocasta",
    "Juno",
    "Kalliope",
    "Kallista",
    "Kallisto",
    "Kallistrate",
    "Kassandra",
    "Katerina",
    "Kirrily",
    "Kleio",
    "Kleonike",
    "Klotho",
    "Kynthia",
    "Kyra",
    "Kyriaki",
    "Lamia",
    "Larisa",
    "Larissa",
    "Lavinia",
    "Leandra",
    "Leda",
    "Ligeia",
    "Lydia",
    "Lyra",
    "Lysandra",
    "Maia",
    "Margarita",
    "Medea",
    "Melaina",
    "Melantha",
    "Melia",
    "Melina",
    "Melissa",
    "Melitta",
    "Naida",
    "Narcissa",
    "Nausicaa",
    "Nefeli",
    "Nephele",
    "Nerissa",
    "Nike",
    "Nikola",
    "Nikolina",
    "Nyx",
    "Oceana",
    "Olympia",
    "Olympias",
    "Ophelia",
    "Orion",
    "Pallas",
    "Pandora",
    "Penelope",
    "Perdita",
    "Persephone",
    "Phaedra",
    "Philippa",
    "Philomena",
    "Philothea",
    "Phoebe",
    "Polyxena",
    "Rhea",
    "Rhodanthe",
    "Rhode",
    "Sappho",
    "Selene",
    "Sophia",
    "Thais",
    "Thalia",
    "Thea",
    "Theodora",
    "Theodosia",
    "Theophania",
    "Theresa",
    "Thetis",
    "Urania",
    "Ursula",
    "Xanthe",
    "Xenia",
    "Yolanda",
    "Zara",
    "Zenobia",
    "Zephyra",
    "Zoe",
]

male_names = [
    "Achaeus",
    "Achilles",
    "Adonis",
    "Adrastos",
    "Aeneas",
    "Aeschylus",
    "Aetios",
    "Agamemnon",
    "Agapetos",
    "Agapios",
    "Agatharchos",
    "Agathias",
    "Agathon",
    "Ajax",
    "Alcibiades",
    "Alcimedon",
    "Alexander",
    "Alexandros",
    "Alkibiades",
    "Alpheus",
    "Amphion",
    "Anaxagoras",
    "Andreas",
    "Antigonus",
    "Apollo",
    "Archelaus",
    "Archimedes",
    "Aristarchus",
    "Aristides",
    "Aristophanes",
    "Aristoteles",
    "Aristotle",
    "Aristoxenos",
    "Artemidorus",
    "Asclepius",
    "Atticus",
    "Bacchus",
    "Barnabas",
    "Basilides",
    "Bellerophon",
    "Bion",
    "Calchas",
    "Calix",
    "Callias",
    "Callimachus",
    "Cassander",
    "Cephalus",
    "Chariton",
    "Chrysippos",
    "Cimon",
    "Cleisthenes",
    "Cleitus",
    "Cleon",
    "Cleopas",
    "Cleophanes",
    "Clytemnestra",
    "Corydon",
    "Crispus",
    "Crito",
    "Cyrus",
    "Damasus",
    "Damon",
    "Darius",
    "Demetrius",
    "Democritus",
    "Demosthenes",
    "Diogenes",
    "Dionysius",
    "Diophantos",
    "Elias",
    "Epaminondas",
    "Ephialtes",
    "Epimetheus",
    "Epiphanes",
    "Eratosthenes",
    "Eudoxos",
    "Eugenios",
    "Eumenides",
    "Euphemios",
    "Euphemius",
    "Euripides",
    "Evander",
    "Fabian",
    "Flavius",
    "Galen",
    "Glycon",
    "Gorgias",
    "Gorgon",
    "Gorgythion",
    "Gregor",
    "Hector",
    "Hecuba",
    "Hegesippus",
    "Helenus",
    "Hephaestus",
    "Heraclitus",
    "Herakles",
    "Hermes",
    "Herodotus",
    "Hesiod",
    "Hippocrates",
    "Hippolytos",
    "Hippolytus",
    "Hippomenes",
    "Homer",
    "Iason",
    "Icarus",
    "Iphicles",
    "Iphicrates",
    "Isidoros",
    "Isidorus",
    "Ismenias",
    "Ismenios",
    "Isocrates",
    "Jamblichus",
    "Jason",
    "Jocasta",
    "Jocastas",
    "Jonas",
    "Julian",
    "Julius",
    "Kallias",
    "Kallisthenes",
    "Kallistos",
    "Kallixenos",
    "Kallixtus",
    "Kleon",
    "Kyros",
    "Laertes",
    "Laonikos",
    "Leander",
    "Leonidas",
    "Lycurgus",
    "Lykophron",
    "Lykourgos",
    "Lysander",
    "Lysandros",
    "Lysimachus",
    "Lysistratos",
    "Makarios",
    "Marcus",
    "Megas",
    "Menander",
    "Menedemos",
    "Metrophanes",
    "Miltiades",
    "Myron",
    "Narcissus",
    "Nereus",
    "Nestor",
    "Nicomachus",
    "Nicomedes",
    "Nikandros",
    "Nikolaos",
    "Nikon",
    "Odysseus",
    "Oedipus",
    "Olympiodorus",
    "Olympios",
    "Olympos",
    "Onesimos",
    "Orestes",
    "Origen",
    "Origenes",
    "Orion",
    "Orosius",
    "Pallas",
    "Pandarus",
    "Paris",
    "Parmenides",
    "Pausanias",
    "Pelias",
    "Pelops",
    "Pentheus",
    "Pericles",
    "Perseus",
    "Petros",
    "Phaedo",
    "Phaedrus",
    "Philemon",
    "Philip",
    "Philo",
    "Philocles",
    "Philoctetes",
    "Philostratos",
    "Philostratus",
    "Phocion",
    "Phoenix",
    "Phoibos",
    "Phokas",
    "Phokion",
    "Phrixus",
    "Plato",
    "Plutarch",
    "Polybius",
    "Polycarp",
    "Polyclitus",
    "Polycrates",
    "Polydamas",
    "Polydeukes",
    "Polykarp",
    "Polykrates",
    "Polynices",
    "Polypemon",
    "Pompey",
    "Ptolemy",
    "Pyrrhos",
    "Pyrrhus",
    "Pythagoras",
    "Quintus",
    "Raphael",
    "Sappho",
    "Satyros",
    "Simonides",
    "Socrates",
    "Solon",
    "Sophocles",
    "Soterios",
    "Stesichorus",
    "Strabo",
    "Sulla",
    "Telemachus",
    "Telesphorus",
    "Thaddeus",
    "Thales",
    "Thamyris",
    "Thargelion",
    "Tharypas",
    "Themistocles",
    "Theocritus",
    "Theodore",
    "Theokritos",
    "Theophanes",
    "Theophrastus",
    "Theophylaktos",
    "Theseus",
    "Thucydides",
    "Timon",
    "Ulysses",
    "Urbanus",
    "Xander",
    "Xanthos",
    "Xanthus",
    "Xenocrates",
    "Xenophon",
    "Xerxes",
    "Xiphos",
    "Xouthos",
    "Zeno",
    "Zephyrus",
    "Zethus",
    "Zopyros",
    "Zosimos",
    "Zoticus",
    "Zotikos",
]

surnames = [
    "of Abydos",
    "of Acamas",
    "of Acarnania",
    "of Achaia",
    "of Aegae",
    "of Aegina",
    "of Aenus",
    "of Aeolis",
    "of Aetolia",
    "of Ainos",
    "of Alalcomenae",
    "of Amaseia",
    "of Amathus",
    "of Ambracia",
    "of Amphipolis",
    "of Amphissa",
    "of Anactorium",
    "of Antandrus",
    "of Antioch",
    "of Aphytis",
    "of Apollonia",
    "of Arcadia",
    "of Arethusa",
    "of Argos",
    "of Astypalaia",
    "of Athens",
    "of Atlantis",
    "of Aulis",
    "of Axus",
    "of Bargylia",
    "of Bithynia",
    "of Boeotia",
    "of Bosphorus",
    "of Brea",
    "of Buthrotum",
    "of Byblos",
    "of Canopus",
    "of Caria",
    "of Caryatis",
    "of Cassandrea",
    "of Chaeronea",
    "of Chalcedon",
    "of Chalcis",
    "of Chios",
    "of Cilicia",
    "of Cnidus",
    "of Colophon",
    "of Corcyra",
    "of Corfu",
    "of Corinth",
    "of Cos",
    "of Crete",
    "of Crisa",
    "of Crocus",
    "of Croton",
    "of Cydonia",
    "of Cyme",
    "of Cyrene",
    "of Cyzicus",
    "of Delium",
    "of Delos",
    "of Delphi",
    "of Dion",
    "of Dodona",
    "of Doris",
    "of Elea",
    "of Eleusis",
    "of Elis",
    "of Ephesus",
    "of Ephyra",
    "of Epidamnus",
    "of Epidaurus",
    "of Epirus",
    "of Eretria",
    "of Eryx",
    "of Euboea",
    "of Eumaeus",
    "of Euphemia",
    "of Galatia",
    "of Gela",
    "of Gortyn",
    "of Halicarnassus",
    "of Halimous",
    "of Hamaxitos",
    "of Helike",
    "of Hellas",
    "of Hellespont",
    "of Heraclea",
    "of Heraea",
    "of Heraklion",
    "of Hermione",
    "of Himera",
    "of Hipponium",
    "of Hyampolis",
    "of Hybla",
    "of Ialysos",
    "of Iasos",
    "of Icaria",
    "of Ilium",
    "of Illyria",
    "of Iolcos",
    "of Ionian",
    "of Ithaca",
    "of Kameiros",
    "of Karia",
    "of Karyes",
    "of Karystos",
    "of Knidos",
    "of Knossos",
    "of Korydallos",
    "of Kos",
    "of Krete",
    "of Kydonia",
    "of Laconia",
    "of Lamia",
    "of Lampsacus",
    "of Lapithos",
    "of Larisa",
    "of Larissa",
    "of Lebadeia",
    "of Lemnos",
    "of Lesbos",
    "of Leucadia",
    "of Lindos",
    "of Locri",
    "of Locris",
    "of Lydia",
    "of Magnesia",
    "of Mantineia",
    "of Marathon",
    "of Marathus",
    "of Megara",
    "of Melos",
    "of Mesembria",
    "of Methone",
    "of Miletus",
    "of Mycenae",
    "of Mylasa",
    "of Myndos",
    "of Myrina",
    "of Mytilene",
    "of Myus",
    "of Naxos",
    "of Neapolis",
    "of Nemea",
    "of Nicaea",
    "of Nile",
    "of Oeantheia",
    "of Olbia",
    "of Olympia",
    "of Olympus",
    "of Olynthos",
    "of Olynthus",
    "of Orestis",
    "of Paeonia",
    "of Pagasae",
    "of Palaepaphos",
    "of Pallene",
    "of Panormus",
    "of Paphos",
    "of Parium",
    "of Paros",
    "of Patara",
    "of Patrai",
    "of Patras",
    "of Pella",
    "of Peloponnesus",
    "of Pelorus",
    "of Peonia",
    "of Pergamon",
    "of Phaestus",
    "of Pharsalus",
    "of Pheneus",
    "of Phigaleia",
    "of Phigalia",
    "of Phlius",
    "of Phocis",
    "of Phrygia",
    "of Phthiotis",
    "of Piraeus",
    "of Pisa",
    "of Pityus",
    "of Plotheia",
    "of Pluronia",
    "of Pluronic",
    "of Poteidaea",
    "of Potidaea",
    "of Priene",
    "of Pteleon",
    "of Pteleum",
    "of Pydna",
    "of Pylos",
    "of Rhamnous",
    "of Rhegium",
    "of Rhodes",
    "of Sais",
    "of Samos",
    "of Sardis",
    "of Scione",
    "of Selinus",
    "of Sestos",
    "of Sicyon",
    "of Sikyon",
    "of Sila",
    "of Sinope",
    "of Sithonia",
    "of Sparta",
    "of Sphagia",
    "of Sphettus",
    "of Sphodrias",
    "of Stymphalus",
    "of Sybaris",
    "of Syracuse",
    "of Tegea",
    "of Tenedos",
    "of Teos",
    "of Teuthrania",
    "of Thasos",
    "of Thebes",
    "of Thera",
    "of Therma",
    "of Thermopylae",
    "of Thessaly",
    "of Thrace",
    "of Thronium",
    "of Thryos",
    "of Thyatira",
    "of Tilos",
    "of Tiryns",
    "of Tithorea",
    "of Torone",
    "of Trachis",
    "of Troezen",
    "of Troy",
    "of Tumulus",
    "of Xanthos",
    "of Zakynthos",
    "of Zancle",
    "of Zephyrion",
    "of Zeus Ammon",
    "of Zoster",
]
