female_prefix = [
    "ai",
    "an",
    "bo",
    "chi",
    "da",
    "en",
    "fu",
    "go",
    "ha",
    "hi",
    "i",
    "ka",
    "ko",
    "mi",
    "na",
    "no",
    "ra",
    "ri",
    "sa",
    "shi",
    "ta",
    "to",
    "tsu",
    "u",
    "ya",
    "yo",
    "zu",
]

female_suffix = [
    "a",
    "aki",
    "ami",
    "aya",
    "chi",
    "e",
    "emi",
    "hana",
    "i",
    "iko",
    "ka",
    "kami",
    "ko",
    "mi",
    "miko",
    "na",
    "nami",
    "no",
    "omi",
    "ra",
    "ri",
    "saki",
    "shi",
    "ta",
    "to",
    "tsuki",
    "u",
    "ya",
    "yo",
]

male_prefix = [
    "ai",
    "ben",
    "chan",
    "da",
    "en",
    "fu",
    "gen",
    "hai",
    "ich",
    "ji",
    "ken",
    "li",
    "ming",
    "nao",
    "ori",
    "po",
    "qing",
    "ren",
    "shen",
    "tai",
    "ui",
    "vui",
    "wen",
    "xi",
    "ya",
    "zen",
]

male_suffix = [
    "bo",
    "chi",
    "do",
    "en",
    "fu",
    "gi",
    "hiro",
    "i",
    "ji",
    "ko",
    "lei",
    "ming",
    "no",
    "ou",
    "po",
    "quan",
    "rong",
    "shi",
    "to",
    "ui",
    "vui",
    "wen",
    "xi",
    "yo",
    "zen",
]

surname_prefix = [
    "chin",
    "da",
    "fu",
    "guan",
    "han",
    "jing",
    "li",
    "mei",
    "ning",
    "qian",
    "rong",
    "shen",
    "ting",
    "wan",
    "xi",
    "yan",
    "zhi",
]

surname_suffix = [
    "bai",
    "chun",
    "feng",
    "hua",
    "ji",
    "lan",
    "mei",
    "nan",
    "ping",
    "qi",
    "rong",
    "shu",
    "ting",
    "wen",
    "xi",
    "yan",
    "ying",
    "zhi",
]

female_names = [
    "Akane",
    "Aki",
    "Akiko",
    "Amaya",
    "Anzu",
    "Aoi",
    "Asuka",
    "Ayame",
    "Chie",
    "Chika",
    "Chisato",
    "Chiyo",
    "Eiko",
    "Emi",
    "Eri",
    "Fujiko",
    "Fumiko",
    "Hana",
    "Hanako",
    "Haru",
    "Haruko",
    "Harumi",
    "Hikari",
    "Hina",
    "Hinata",
    "Hiroko",
    "Hisako",
    "Hitomi",
    "Honoka",
    "Hotaru",
    "Ikue",
    "Ikuko",
    "Inari",
    "Izumi",
    "Kaede",
    "Kaho",
    "Kameko",
    "Kasumi",
    "Katsuko",
    "Kazuko",
    "Kiku",
    "Kimiko",
    "Kiyo",
    "Kiyoko",
    "Kumiko",
    "Kyoko",
    "Mai",
    "Maki",
    "Mami",
    "Mana",
    "Mao",
    "Mari",
    "Mariko",
    "Masako",
    "Mayu",
    "Mayumi",
    "Megumi",
    "Michiko",
    "Midori",
    "Mieko",
    "Mika",
    "Miki",
    "Miku",
    "Minako",
    "Minori",
    "Misaki",
    "Misako",
    "Mitsuko",
    "Miyako",
    "Miyu",
    "Miyuki",
    "Momoko",
    "Mutsuko",
    "Nami",
    "Namiko",
    "Naoko",
    "Natsuko",
    "Natsumi",
    "Nobuko",
    "Nori",
    "Noriko",
    "Rei",
    "Reiko",
    "Rie",
    "Riko",
    "Rina",
    "Risa",
    "Ryoko",
    "Sachiko",
    "Saki",
    "Sakura",
    "Satoko",
    "Sayuri",
    "Setsuko",
    "Shinobu",
    "Shiori",
    "Shizuka",
    "Sumiko",
    "Takako",
    "Takara",
    "Takiko",
    "Tamiko",
    "Toshiko",
    "Umeko",
    "Wakana",
    "Yasuko",
    "Yayoi",
    "Yoko",
    "Yoshie",
    "Yoshiko",
    "Yui",
    "Yuka",
    "Yukari",
    "Yuki",
    "Yukiko",
    "Yumi",
    "Yumiko",
    "Yuriko",
    "Yuu",
    "Yuuko",
    "Yuuna",
    "Yuzu",
    "Yuzuki",
    "Yuzuko",
]

male_names = [
    "Akihiko",
    "Akihiro",
    "Akihito",
    "Akio",
    "Akira",
    "Arata",
    "Atsushi",
    "Chikao",
    "Daichi",
    "Daisuke",
    "Eiji",
    "Fujio",
    "Fumio",
    "Goro",
    "Hachiro",
    "Hajime",
    "Haru",
    "Haruki",
    "Haruto",
    "Hideaki",
    "Hideo",
    "Hideyoshi",
    "Hikaru",
    "Hiroaki",
    "Hiroki",
    "Hiroshi",
    "Hisashi",
    "Hitoshi",
    "Ichiro",
    "Isamu",
    "Itaru",
    "Jiro",
    "Jun",
    "Junichi",
    "Katsuo",
    "Katsuro",
    "Kazuhiko",
    "Kazuhiro",
    "Kazuki",
    "Kazuo",
    "Kei",
    "Keiji",
    "Keisuke",
    "Ken",
    "Kenichi",
    "Kenshin",
    "Kenta",
    "Kiyoshi",
    "Koichi",
    "Koji",
    "Kosuke",
    "Makoto",
    "Mamoru",
    "Masahiro",
    "Masaki",
    "Masanori",
    "Masao",
    "Masashi",
    "Masato",
    "Michio",
    "Minoru",
    "Mitsuo",
    "Naoki",
    "Naoto",
    "Noboru",
    "Nobu",
    "Nobuyuki",
    "Norio",
    "Osamu",
    "Ryo",
    "Ryota",
    "Ryozo",
    "Saburo",
    "Satoshi",
    "Seiji",
    "Shigeo",
    "Shin",
    "Shingo",
    "Shinichi",
    "Shinji",
    "Shinsuke",
    "Shiro",
    "Sho",
    "Shohei",
    "Shota",
    "Shuichi",
    "Shun",
    "Susumu",
    "Tadao",
    "Tadashi",
    "Takao",
    "Takashi",
    "Takehiko",
    "Takeshi",
    "Takumi",
    "Takuya",
    "Taro",
    "Tatsuo",
    "Tatsuya",
    "Tetsuo",
    "Tetsuya",
    "Tomio",
    "Tomohiro",
    "Tomohisa",
    "Tomoki",
    "Tomonori",
    "Toru",
    "Toshiaki",
    "Toshihiro",
    "Toshio",
    "Toshiro",
    "Toshiyuki",
    "Tsuyoshi",
    "Wataru",
    "Yasuo",
    "Yasushi",
    "Yasuyuki",
    "Yoichi",
    "Yoshiaki",
    "Yoshikazu",
    "Yoshinori",
    "Yoshio",
    "Yoshiro",
    "Yosuke",
    "Yota",
    "Yuji",
    "Yuki",
    "Yukio",
    "Yusuke",
    "Yutaka",
    "Yuya",
    "Zenjiro",
]

surnames = [
    "Abe",
    "Akaike",
    "Amaya",
    "Aoki",
    "Asakawa",
    "Chiba",
    "Daigo",
    "Ebina",
    "Enoki",
    "Fujii",
    "Fukuda",
    "Goto",
    "Hamasaki",
    "Haneda",
    "Hara",
    "Harada",
    "Hashimoto",
    "Hattori",
    "Hayashi",
    "Higashi",
    "Hirano",
    "Hirose",
    "Hosokawa",
    "Igarashi",
    "Iida",
    "Ikegami",
    "Inoue",
    "Ishida",
    "Ishikawa",
    "Ishiyama",
    "Itami",
    "Iwai",
    "Iwamoto",
    "Iwasaki",
    "Kagawa",
    "Kajiwara",
    "Kaneko",
    "Kato",
    "Kawaguchi",
    "Kawamoto",
    "Kishimoto",
    "Kobayashi",
    "Koga",
    "Kojima",
    "Komatsu",
    "Kondo",
    "Kubota",
    "Kudo",
    "Kuroda",
    "Maeda",
    "Matsuda",
    "Matsui",
    "Matsuo",
    "Matsushita",
    "Mizuno",
    "Morikawa",
    "Morioka",
    "Moriyama",
    "Nagai",
    "Nagano",
    "Nagata",
    "Nakagawa",
    "Nakajima",
    "Nakamura",
    "Nakanishi",
    "Nakano",
    "Nakayama",
    "Nishida",
    "Nishimura",
    "Nishio",
    "Nishiyama",
    "Ogawa",
    "Ohashi",
    "Oishi",
    "Okamoto",
    "Okamura",
    "Okubo",
    "Ota",
    "Saito",
    "Sakaguchi",
    "Sakamoto",
    "Sasaki",
    "Sato",
    "Sawai",
    "Sawamura",
    "Shibata",
    "Shimada",
    "Shimizu",
    "Shimomura",
    "Shinohara",
    "Shiota",
    "Sugawara",
    "Sugiyama",
    "Suzuki",
    "Takahashi",
    "Takai",
    "Takamoto",
    "Takanashi",
    "Takano",
    "Takeda",
    "Takei",
    "Tamura",
    "Tanaka",
    "Tokunaga",
    "Tomita",
    "Tsuchiya",
    "Tsujimoto",
    "Tsujita",
    "Uchida",
    "Ueda",
    "Uesugi",
    "Umeda",
    "Wada",
    "Watanabe",
    "Yamada",
    "Yamaguchi",
    "Yamamoto",
    "Yamashita",
    "Yamazaki",
    "Yano",
    "Yokoyama",
    "Yoneda",
    "Yoshida",
    "Yoshikawa",
    "Yoshimoto",
    "Yoshizawa",
]
