female_suffix = [
    "a",
    "bel",
    "cia",
    "da",
    "el",
    "fae",
    "gwyn",
    "hia",
    "i",
    "ja",
    "ka",
    "la",
    "ma",
    "na",
    "ora",
    "pa",
    "qua",
    "ra",
    "sa",
    "ta",
    "ula",
    "va",
    "wa",
    "xa",
    "ya",
    "za",
    "belle",
    "cey",
    "dine",
    "elle",
    "finn",
    "grace",
    "hira",
    "ira",
    "jade",
    "kara",
    "lynn",
    "mara",
    "nora",
    "opal",
    "phina",
    "quella",
    "rina",
    "sera",
    "tia",
    "una",
    "vella",
    "wren",
    "xina",
    "yara",
    "zara",
]

male_prefix = [
    "ach",
    "an",
    "ar",
    "bal",
    "be",
    "bel",
    "bran",
    "cal",
    "cor",
    "dar",
    "de",
    "del",
    "dra",
    "er",
    "fis",
    "gal",
    "gar",
    "ha",
    "he",
    "hir",
    "il",
    "ja",
    "kel",
    "kor",
    "lar",
    "le",
    "li",
    "ma",
    "mar",
    "na",
    "nor",
    "ol",
    "on",
    "pa",
    "pel",
    "per",
    "qua",
    "ra",
    "ran",
    "rel",
    "ro",
    "sa",
    "sar",
    "sel",
    "tar",
    "te",
    "ti",
    "to",
    "ur",
    "va",
    "var",
    "vel",
    "ver",
    "wa",
    "wal",
    "ya",
    "yar",
    "zel",
]

male_suffix = [
    "ad",
    "al",
    "an",
    "ar",
    "as",
    "av",
    "don",
    "dor",
    "el",
    "en",
    "er",
    "es",
    "gan",
    "har",
    "hor",
    "ian",
    "ic",
    "id",
    "il",
    "in",
    "is",
    "kan",
    "kar",
    "kas",
    "lak",
    "las",
    "lin",
    "lon",
    "mar",
    "mon",
    "nan",
    "nar",
    "nas",
    "non",
    "or",
    "rad",
    "ran",
    "ras",
    "rik",
    "ron",
    "sal",
    "san",
    "tas",
    "tar",
    "tin",
    "ton",
    "ur",
    "us",
    "van",
    "var",
    "ver",
    "von",
    "war",
    "won",
    "yas",
    "zan",
    "zen",
    "zon",
]

female_prefix = [
    "acht",
    "bry",
    "cali",
    "dara",
    "ell",
    "fay",
    "gwen",
    "hela",
    "is",
    "jen",
    "kala",
    "lara",
    "morga",
    "nala",
    "orla",
    "pae",
    "quen",
    "rae",
    "sab",
    "tara",
    "ulan",
    "vay",
    "wyn",
    "xan",
    "yara",
    "zara",
    "bel",
    "cara",
    "dela",
    "ella",
    "fin",
    "grace",
    "hira",
    "ira",
    "jenna",
    "kira",
    "luna",
    "maia",
    "nira",
    "opal",
    "pippa",
    "quela",
    "rona",
    "saffron",
    "tessa",
    "ula",
    "vanna",
    "willa",
    "xara",
    "yuna",
    "zella",
]

surname_syllables = [
    "al",
    "an",
    "ar",
    "ark",
    "as",
    "ash",
    "ba",
    "bar",
    "be",
    "bel",
    "car",
    "cas",
    "cor",
    "da",
    "dal",
    "dar",
    "de",
    "del",
    "di",
    "don",
    "dor",
    "el",
    "en",
    "er",
    "es",
    "fal",
    "far",
    "fi",
    "gal",
    "gar",
    "har",
    "ho",
    "ian",
    "ik",
    "il",
    "in",
    "is",
    "ja",
    "jar",
    "kal",
    "kar",
    "kas",
    "ken",
    "kor",
    "lar",
    "li",
    "lon",
    "ma",
    "mal",
    "mar",
    "mas",
    "mon",
    "na",
    "nal",
    "nar",
    "ni",
    "no",
    "on",
    "or",
    "pa",
    "par",
    "per",
    "qu",
    "ra",
    "ral",
    "ran",
    "ri",
    "ril",
    "ro",
    "ron",
    "sa",
    "sal",
    "sha",
    "si",
    "st",
    "ta",
    "tar",
    "th",
    "thal",
    "thar",
    "thon",
    "ti",
    "tin",
    "tor",
    "un",
    "ur",
    "va",
    "val",
    "var",
    "ver",
    "von",
    "wan",
    "war",
    "wen",
    "win",
    "ya",
    "yar",
    "yen",
    "yin",
    "yor",
    "za",
    "zan",
    "zar",
]

female_names = [
    "Abigail",
    "Ada",
    "Adelaide",
    "Adriana",
    "Alessandra",
    "Alexandra",
    "Alexandria",
    "Amara",
    "Anastasia",
    "Arabella",
    "Aria",
    "Ava",
    "Beatrice",
    "Belle",
    "Bianca",
    "Brianna",
    "Briar",
    "Brielle",
    "Bronwyn",
    "Brynn",
    "Calista",
    "Calliope",
    "Camilla",
    "Cara",
    "Cassandra",
    "Cassiopeia",
    "Charlotte",
    "Clara",
    "Cleo",
    "Dahlia",
    "Daisy",
    "Dana",
    "Daphne",
    "Dara",
    "Delia",
    "Delilah",
    "Della",
    "Delphine",
    "Demetria",
    "Desdemona",
    "Diana",
    "Eden",
    "Eleanor",
    "Elena",
    "Elisabeth",
    "Elle",
    "Eloise",
    "Esmeralda",
    "Eva",
    "Evangeline",
    "Evelyn",
    "Faye",
    "Felicity",
    "Fiona",
    "Fiora",
    "Fleur",
    "Flora",
    "Freya",
    "Gabriella",
    "Gemma",
    "Genevieve",
    "Georgina",
    "Giselle",
    "Grace",
    "Guinevere",
    "Gwen",
    "Gwendolyn",
    "Halle",
    "Hannah",
    "Harper",
    "Hazel",
    "Helena",
    "Hermione",
    "Holly",
    "Imogen",
    "Iris",
    "Isabella",
    "Isabelle",
    "Isadora",
    "Isla",
    "Isolde",
    "Ivy",
    "Jade",
    "Jessamine",
    "Jocelyn",
    "Josephine",
    "Julia",
    "Juliana",
    "Juliette",
    "June",
    "Juno",
    "Kalliope",
    "Kassandra",
    "Katarina",
    "Kate",
    "Katerina",
    "Katherine",
    "Kathleen",
    "Keira",
    "Kiera",
    "Kira",
    "Lara",
    "Lavinia",
    "Leilani",
    "Lena",
    "Lila",
    "Liliana",
    "Lily",
    "Lorelei",
    "Luna",
    "Lyra",
    "Madeline",
    "Maeve",
    "Magdalena",
    "Margot",
    "Matilda",
    "Melisande",
    "Melissa",
    "Mila",
    "Mira",
    "Miranda",
    "Morgana",
    "Nadia",
    "Natalia",
    "Natalie",
    "Nerissa",
    "Nia",
    "Nicolette",
    "Nina",
    "Nora",
    "Octavia",
    "Odessa",
    "Odette",
    "Olive",
    "Olivia",
    "Olympia",
    "Ophelia",
    "Paige",
    "Penelope",
    "Persephone",
    "Piper",
    "Poppy",
    "Primrose",
    "Priscilla",
    "Queenie",
    "Quiana",
    "Quincy",
    "Quinn",
    "Quinta",
    "Quintessa",
    "Rae",
    "Ravenna",
    "Rhiannon",
    "Rosalie",
    "Rosalind",
    "Rose",
    "Rowena",
    "Roxanne",
    "Ruby",
    "Sabrina",
    "Sage",
    "Seraphina",
    "Serena",
    "Skye",
    "Sophia",
    "Stella",
    "Talia",
    "Tallulah",
    "Tatiana",
    "Tess",
    "Tessa",
    "Thalia",
    "Thea",
    "Theodora",
    "Theresa",
    "Ursula",
    "Valentina",
    "Valeria",
    "Vera",
    "Veronica",
    "Vespera",
    "Victoria",
    "Violet",
    "Vivian",
    "Vivienne",
    "Wilhelmina",
    "Willa",
    "Willow",
    "Winifred",
    "Winona",
    "Wren",
    "Xanthe",
    "Xanthia",
    "Xena",
    "Xenia",
    "Xiomara",
    "Yara",
    "Yasmin",
    "Yasmine",
    "Yvaine",
    "Yvette",
    "Yvonne",
    "Zara",
    "Zephyra",
    "Zephyrine",
    "Zinnia",
    "Zoe",
]

male_names = [
    "Aek",
    "Aldan",
    "Aman",
    "Anomander",
    "Anton",
    "Apt",
    "Aran",
    "Ard",
    "Arvid",
    "Asik",
    "Astol",
    "Bak",
    "Bard",
    "Bardin",
    "Baruk",
    "Bellurdan",
    "Ben",
    "Bluerose",
    "Braven",
    "Bryce",
    "Bugg",
    "Cal",
    "Cam",
    "Challice",
    "Cob",
    "Cord",
    "Cot",
    "Cotillion",
    "Cowl",
    "Crok",
    "Crone",
    "Cropp",
    "Crump",
    "Cul",
    "Dace",
    "Dalon",
    "Dancer",
    "Darujhistan",
    "Das",
    "Dassem",
    "Derudan",
    "Detoran",
    "Dismal",
    "Dodge",
    "Duiker",
    "Dunsparrow",
    "Durav",
    "Dwite",
    "Ebbin",
    "Edgewalker",
    "Edur",
    "Ell",
    "Emancipor",
    "Enas",
    "Envy",
    "Erikson",
    "Esbek",
    "Faint",
    "Faradan",
    "Farloe",
    "Feather",
    "Fell",
    "Fiddler",
    "Fingers",
    "Fool",
    "Ganoes",
    "Gedderone",
    "Gentleman",
    "Gesler",
    "Gethol",
    "Giggle",
    "Gleam",
    "Gothos",
    "Grim",
    "Grub",
    "Gruntle",
    "Gryllen",
    "Gurl",
    "Hairlock",
    "Halfpeck",
    "Halt",
    "Harllo",
    "Harth",
    "Heboric",
    "Hedge",
    "Helian",
    "Helm",
    "Hentos",
    "Hess",
    "Hew",
    "Hood",
    "Hope",
    "Hull",
    "Hum",
    "Hunch",
    "Hunthult",
    "Icarium",
    "Imp",
    "Ironbars",
    "Iskar",
    "Itkovian",
    "Jal",
    "Jan",
    "Jardir",
    "Jhenna",
    "Jib",
    "Kal",
    "Kalam",
    "Karsa",
    "Kedeviss",
    "Keneb",
    "Kilmandaros",
    "Kiska",
    "Korbolo",
    "Kruppe",
    "Kurzin",
    "Lar",
    "Laseen",
    "Lawn",
    "Leaf",
    "Leoman",
    "Limp",
    "Little",
    "Lobe",
    "Lorn",
    "Lostara",
    "Lutes",
    "Mallet",
    "Mapo",
    "Mappo",
    "Maral",
    "Marill",
    "Masan",
    "Maw",
    "Mist",
    "Mogora",
    "Mok",
    "Molander",
    "Moon",
    "Morn",
    "Mottle",
    "Mouse",
    "Mule",
    "Munug",
    "Murr",
    "Nefarias",
    "Nether",
    "Nil",
    "Nimander",
    "Nok",
    "Noon",
    "Noto",
    "Obo",
    "Oponn",
    "Orbyn",
    "Ord",
    "Ormulogun",
    "Paralt",
    "Paran",
    "Pate",
    "Pearl",
    "Pella",
    "Pest",
    "Picker",
    "Pilip",
    "Pithy",
    "Pores",
    "Pormqual",
    "Pran",
    "Quick",
    "Raest",
    "Rain",
    "Rake",
    "Rallick",
    "Ramp",
    "Rat",
    "Rath",
    "Raven",
    "Redmask",
    "Rhulad",
    "Rissarh",
    "Roach",
    "Rotch",
    "Ryllandaras",
    "Samar",
    "Sandalath",
    "Sands",
    "Sawark",
    "Scar",
    "Scillara",
    "Scorch",
    "Senu",
    "Sever",
    "Shadowthrone",
    "Shake",
    "Shaky",
    "Shardan",
    "Shaven",
    "Shimmer",
    "Siballe",
    "Sight",
    "Sil",
    "Silchas",
    "Skintick",
    "Skorgen",
    "Skovald",
    "Skullcup",
    "Skulldeath",
    "Sleek",
    "Slink",
    "Smack",
    "Smiles",
    "Snell",
    "Spindle",
    "Squint",
    "Stalker",
    "Stavi",
    "Steep",
    "Stork",
    "Stormy",
    "Stryke",
    "Studlock",
    "Sudden",
    "Sump",
    "Sword",
    "Talamandas",
    "Tanas",
    "Tanno",
    "Tattersail",
    "Tayschrenn",
    "Teal",
    "Tehol",
    "Temper",
    "Temul",
    "Tene",
    "Thelomen",
    "Throatslitter",
    "Tick",
    "Toc",
    "Togg",
    "Tool",
    "Torvald",
    "Trail",
    "Trake",
    "Tree",
    "Trotts",
    "Trull",
    "Tulas",
    "Tulip",
    "Turban",
    "Turlow",
    "Twilight",
    "Twist",
    "Ublala",
    "Udinaas",
    "Ullen",
    "Urb",
    "Urko",
    "Ursto",
    "Uru",
    "Valan",
    "Vandal",
    "Vastly",
    "Ved",
    "Vedith",
    "Venitt",
    "Verdith",
    "Vigor",
    "Vorcan",
    "Wahr",
    "Wan",
    "Wander",
    "Wane",
    "Wave",
    "Weasel",
    "Whiskeyjack",
    "Wickan",
    "Widdershins",
    "Willis",
    "Wish",
    "Woke",
    "Woolie",
    "Worry",
    "Yan",
    "Yath",
    "Yedan",
    "Yghatan",
    "Yil",
    "Yusek",
    "Yuupe",
    "Zar",
    "Zaravow",
    "Zed",
    "Zelman",
    "Zephyr",
    "Zeth",
    "Zol",
    "Zolan",
]

surnames = [
    "Albel",
    "Ancorril",
    "Anroyin",
    "Aril",
    "Arkanhar",
    "Arkas",
    "Arkashran",
    "Arkyarth",
    "Armar",
    "Artorbar",
    "Ashil",
    "Ashlon",
    "Ashsa",
    "Ashsalur",
    "Ashtar",
    "Assithon",
    "Bakarvar",
    "Baonmar",
    "Baperer",
    "Barfal",
    "Barin",
    "Barsal",
    "Bathar",
    "Beashvar",
    "Belalkas",
    "Belaswen",
    "Belzarzar",
    "Betardal",
    "Carjaron",
    "Casel",
    "Caspa",
    "Castitar",
    "Casur",
    "Cornoyin",
    "Daldalel",
    "Darron",
    "Dedi",
    "Deinral",
    "Dekasfal",
    "Delthongal",
    "Dest",
    "Diash",
    "Dibarin",
    "Dijarde",
    "Diti",
    "Dondiral",
    "Dorharwan",
    "Elvervar",
    "Enva",
    "Enyakor",
    "Erbelgar",
    "Eres",
    "Eril",
    "Ersa",
    "Erst",
    "Falni",
    "Falwan",
    "Fiarkdor",
    "Ficas",
    "Galta",
    "Garas",
    "Garst",
    "Harnoark",
    "Hodeles",
    "Ikkal",
    "Iklar",
    "Ikridi",
    "Illarqu",
    "Inkor",
    "Inorzan",
    "Ishar",
    "Islihar",
    "Isran",
    "Isver",
    "Jagal",
    "Jaharya",
    "Jalarcar",
    "Jarnoth",
    "Kaldarral",
    "Kaldeno",
    "Kaldoncar",
    "Kalgarjar",
    "Kallon",
    "Kardonark",
    "Karfaril",
    "Karik",
    "Kasvalash",
    "Kenlar",
    "Kenparil",
    "Kornalbar",
    "Korurmar",
    "Laralik",
    "Larbe",
    "Larin",
    "Larmon",
    "Londitor",
    "Lonfar",
    "Mafi",
    "Maldalkor",
    "Malkor",
    "Malsa",
    "Mares",
    "Marthon",
    "Masas",
    "Masst",
    "Mathalsha",
    "Mondethon",
    "Nabequ",
    "Nafal",
    "Naldorva",
    "Nalfal",
    "Naljawin",
    "Narashde",
    "Nargarsal",
    "Nielwan",
    "Nikorark",
    "Nimapar",
    "Nodar",
    "Nojar",
    "Nowar",
    "Onianin",
    "Onper",
    "Orunhar",
    "Pawan",
    "Pawen",
    "Racaris",
    "Rador",
    "Raeras",
    "Rafarper",
    "Ralran",
    "Ralvonken",
    "Ranashtar",
    "Ranfi",
    "Ranilper",
    "Ranva",
    "Ranvon",
    "Raralri",
    "Rawar",
    "Rima",
    "Romal",
    "Roner",
    "Rowarsal",
    "Sacaslar",
    "Salon",
    "Saltin",
    "Sayen",
    "Sili",
    "Sitin",
    "Stash",
    "Stilda",
    "Stnar",
    "Stshade",
    "Stsi",
    "Stsiun",
    "Tapar",
    "Tardonun",
    "Thalbaron",
    "Thaliktin",
    "Thalronlar",
    "Tharcartor",
    "Thbe",
    "Thmarel",
    "Thsi",
    "Thwin",
    "Tiunkal",
    "Torkal",
    "Torva",
    "Untor",
    "Urarkthal",
    "Urdelqu",
    "Urgal",
    "Urver",
    "Vahargal",
    "Vallon",
    "Valon",
    "Valva",
    "Vazanbe",
    "Veren",
    "Verisde",
    "Verken",
    "Vertival",
    "Vonel",
    "Wankason",
    "Wanmarmal",
    "Waron",
    "Wenkasth",
    "Wenta",
    "Winhofal",
    "Yarlar",
    "Yarlaris",
    "Yaurlon",
    "Yenmartor",
    "Yenri",
    "Yentharis",
    "Yenzan",
    "Yorbelsa",
    "Zadonthal",
    "Zanal",
    "Zapaash",
]
