female_prefix = [
    "ac",
    "atl",
    "ca",
    "ce",
    "ci",
    "co",
    "cu",
    "ehe",
    "eya",
    "hua",
    "ihi",
    "iht",
    "ix",
    "nan",
    "net",
    "nix",
    "pa",
    "pan",
    "pap",
    "pat",
    "pix",
    "que",
    "qui",
    "quim",
    "quit",
    "te",
    "tel",
    "tet",
    "tla",
    "tlah",
    "tle",
    "tli",
    "tlil",
    "tlip",
    "tlot",
    "to",
    "toc",
    "ton",
    "toz",
    "ya",
    "yac",
    "yan",
    "yau",
    "yo",
    "zac",
    "zan",
    "zet",
    "zo",
]

female_suffix = [
    "a",
    "ac",
    "ach",
    "al",
    "amal",
    "atl",
    "ayotl",
    "coyotl",
    "e",
    "eh",
    "etl",
    "huac",
    "icu",
    "ih",
    "il",
    "in",
    "ixtli",
    "iyotl",
    "lauh",
    "liztli",
    "ma",
    "mal",
    "mecatl",
    "mi",
    "nah",
    "nal",
    "ni",
    "niztli",
    "qui",
    "quih",
    "quixtli",
    "tli",
    "tlil",
    "tlixtli",
    "tzin",
    "xi",
    "xih",
    "xihuitl",
    "xoch",
    "yaotl",
    "yoh",
    "yohtl",
    "yol",
    "yolt",
    "ztli",
    "ztoc",
    "zton",
]

male_prefix = [
    "ac",
    "ahu",
    "atl",
    "ca",
    "calli",
    "chi",
    "co",
    "cua",
    "cuauh",
    "ehe",
    "hue",
    "hua",
    "ic",
    "it",
    "itz",
    "iuh",
    "ma",
    "me",
    "miqui",
    "mo",
    "nec",
    "nequi",
    "nel",
    "oco",
    "ohu",
    "op",
    "oy",
    "quauh",
    "quim",
    "tac",
    "tla",
    "tlac",
    "tlal",
    "tlan",
    "tlap",
    "tlat",
    "tlau",
    "tlax",
    "tlil",
    "to",
    "tocht",
    "tol",
    "tona",
    "top",
    "tzi",
    "xi",
    "xim",
    "ya",
    "yac",
    "yauh",
    "yi",
    "yol",
    "yohu",
    "zac",
    "zahui",
    "zal",
    "zitl",
]

male_suffix = [
    "ac",
    "ach",
    "ahual",
    "amatl",
    "ani",
    "atl",
    "auh",
    "calli",
    "catl",
    "chitl",
    "coatl",
    "eh",
    "huey",
    "huic",
    "huitl",
    "ic",
    "itl",
    "iuhtli",
    "mecatl",
    "mi",
    "nacatl",
    "nahual",
    "nahui",
    "nan",
    "nauac",
    "necatl",
    "neh",
    "nochtli",
    "oa",
    "ol",
    "oqu",
    "qui",
    "quiztli",
    "tecatl",
    "temoc",
    "teo",
    "tep",
    "tlahto",
    "tlalli",
    "tlaloc",
    "tlan",
    "tlapal",
    "tlauh",
    "tlaz",
    "tli",
    "tlil",
    "tocatl",
    "ton",
    "topiltz",
    "totl",
    "tzin",
    "xiu",
    "xoc",
    "yahu",
    "yecatl",
    "yohu",
    "zac",
    "zacatl",
    "zalt",
]

surname_prefix = [
    "ac",
    "atl",
    "co",
    "cuauh",
    "eh",
    "huitz",
    "ixt",
    "itz",
    "mec",
    "nahu",
    "ne",
    "o",
    "pah",
    "tla",
    "tecu",
    "tep",
    "tetl",
    "tlac",
    "tlan",
    "tlap",
    "tlat",
    "tlax",
    "tlay",
    "toc",
    "tocht",
    "tzi",
    "ya",
    "yac",
    "yah",
    "yol",
    "zac",
    "zoc",
]

surname_suffix = [
    "an",
    "atl",
    "coatl",
    "ehuac",
    "ic",
    "il",
    "itl",
    "itzin",
    "lini",
    "li",
    "mecatl",
    "motl",
    "nahual",
    "pilli",
    "qui",
    "tli",
    "tlil",
    "tontli",
    "tzi",
    "tzin",
    "tzintli",
    "yaotl",
    "ye",
    "yotl",
    "zon",
]

female_names = [
    "Acatl",
    "Ahuic",
    "Amoxtli",
    "Atlacoya",
    "Ayauhcihuatl",
    "Chalchiuhtlicue",
    "Chicomecoatl",
    "Chimalli",
    "Chimalmatl",
    "Cihuacoatl",
    "Cipactli",
    "Citlali",
    "Coatl",
    "Coyolxauhqui",
    "Cualli",
    "Cuetlaxochitl",
    "Cuixtli",
    "Ehecatl",
    "Eloxochitl",
    "Etl",
    "Huehuecoyotl",
    "Ilhicamina",
    "Itzcoatl",
    "Itzel",
    "Ixchel",
    "Iztac",
    "Iztacihuatl",
    "Iztli",
    "Iztpapalotl",
    "Mazatl",
    "Mictlancihuatl",
    "Mictlantecuhtli",
    "Miquiztli",
    "Nahuatl",
    "Namacuix",
    "Necahual",
    "Nenetl",
    "Nochtli",
    "Ollin",
    "Opochtli",
    "Patecatl",
    "Piltzintli",
    "Quauhtli",
    "Quetzalcoatl",
    "Tecpatl",
    "Teicuih",
    "Tepeyollotl",
    "Tezcacoatl",
    "Tlacaelel",
    "Tlachinolli",
    "Tlaco",
    "Tlahuizcalpantecuhtli",
    "Tlaloc",
    "Tlalocan",
    "Tlalocayotl",
    "Tlalpan",
    "Tlanextli",
    "Tlapalli",
    "Tlatlauhqui",
    "Tlatzolli",
    "Tlazolteotl",
    "Tlecuhtli",
    "Tochintli",
    "Tochtepec",
    "Tochtli",
    "Toci",
    "Toltecatl",
    "Tonalli",
    "Tonalnan",
    "Tonalpohualli",
    "Tonalteotl",
    "Tonantzin",
    "Topiltzin",
    "Totochtin",
    "Totoquihuatzin",
    "Tzitzimitl",
    "Xihuitl",
    "Xilonen",
    "Xipe",
    "Xipil",
    "Xipilli",
    "Xiuh",
    "Xiuhcoatl",
    "Xiuhcozatl",
    "Xiuhtecuhtli",
    "Xiuhtlatl",
    "Xochipilli",
    "Xochiquetzal",
    "Xochiqui",
    "Xochitl",
    "Xochitli",
    "Xoco",
    "Xocoatl",
    "Yacotzin",
    "Yacuicatl",
    "Yanamari",
    "Yaocihuatl",
    "Yauhtli",
    "Yayauhqui",
    "Yazpikua",
    "Yohualli",
    "Yohualticitl",
    "Yolcuat",
    "Yollotl",
    "Yolotl",
    "Yolotzin",
    "Yolotzintli",
    "Yolyamanitzin",
    "Yoxallin",
    "Yoxemil",
    "Yoxiuh",
    "Yoxonotli",
    "Yoyontzin",
    "Zacatzin",
    "Zacualpan",
    "Zani",
    "Zaquitl",
    "Zitlalpopoca",
    "Zitlalxochitl",
    "Zitlalzin",
    "Zolin",
    "Zontecomatl",
    "Zoqui",
]

male_names = [
    "Acalan",
    "Acatl",
    "Achiuhtli",
    "Acolnahuacatl",
    "Acolmiztli",
    "Acolmiztle",
    "Ahcalotl",
    "Ahuítzotl",
    "Ahtahkakoop",
    "Ahtziri",
    "Amacui",
    "Ameyal",
    "Amoxtli",
    "Amoxtzin",
    "Atlixcatzin",
    "Atotonilco",
    "Ayacahuite",
    "Ayauhtzin",
    "Cacamatzin",
    "Cacauatzin",
    "Cachi",
    "Camaxtli",
    "Camaxtzin",
    "Canauhtli",
    "Caxcan",
    "Chalchiuhtlatonac",
    "Chalchiuhtlatonatzin",
    "Chalmecatl",
    "Chaltonac",
    "Chantico",
    "Chiauhque",
    "Chicomexochtli",
    "Chimalpopoca",
    "Cihuaton",
    "Cipactli",
    "Cipriano",
    "Citlalatonac",
    "Citlalatonatzin",
    "Coatl",
    "Coatlaxopeuh",
    "Cochitlehua",
    "Cojontli",
    "Copil",
    "Coyolchiuhqui",
    "Cualli",
    "Cuauhtémoc",
    "Cuauhtemōx",
    "Cuauhtémotz",
    "Cuauhtemōtzin",
    "Cuauhtli",
    "Cuautle",
    "Cuetlachtli",
    "Cuitláhuac",
    "Cuitlauac",
    "Cuitlahuac",
    "Cuxirimay",
    "Ehecatl",
    "Eloxochitl",
    "Huehuetoca",
    "Huemac",
    "Huematzin",
    "Huexotzinco",
    "Huitzilihuitl",
    "Huitzitzilin",
    "Huitzilopochtli",
    "Huitznahua",
    "Huixtocihuatl",
    "Hueyapan",
    "Ichtaca",
    "Itzcoatl",
    "Itzli",
    "Itztli",
    "Ixcoatl",
    "Ixtli",
    "Ixtlilcueitl",
    "Ixtlilxochitl",
    "Ixtilton",
    "Ixtolinqui",
    "Macuil",
    "Malinalxochitl",
    "Mazatl",
    "Meztli",
    "Mictlantecuhtli",
    "Mictlancihuatl",
    "Mictlantecutli",
    "Miztli",
    "Moctezuma",
    "Moctezumatzin",
    "Molinan",
    "Nahuitl",
    "Namacuix",
    "Nanahuatzin",
    "Napay",
    "Necalli",
    "Necuametl",
    "Nezahualcóyotl",
    "Nexahualpilli",
    "Nexahualpillia",
    "Nochtli",
    "Noxochicoztli",
    "Noxochitl",
    "Ohtli",
    "Olin",
    "Opochtli",
    "Oquichtli",
    "Otomitl",
    "Papalotl",
    "Patli",
    "Pilam",
    "Piltzintecuhtli",
    "Piltzintli",
    "Popocatépetl",
    "Quauhtli",
    "Quauitl",
    "Quetzalcoatl",
    "Quintilio",
    "Tecpaocelotl",
    "Tecpatl",
    "Tepiltzin",
    "Tepeyollotl",
    "Tequihuah",
    "Teuhtli",
    "Teyacapan",
    "Teyacapanecatl",
    "Tezcacoatl",
    "Tezcatlipoca",
    "Tezozomoc",
    "Tezozomoctli",
    "Tihtlán",
    "Tlahuicole",
    "Tlaloc",
    "Tlalocatl",
    "Tlalocihuatl",
    "Tlalli",
    "Tlaltecatzin",
    "Tlaltecuhtli",
    "Tlamacazqui",
    "Tlamatzincatl",
    "Tlilpotonqui",
    "Tliltzin",
    "Tocatl",
    "Tochtli",
    "Toxcatl",
    "Tutlahui",
    "Tzilacatzin",
    "Tzitzimitl",
    "Tzonpantli",
    "Uemac",
    "Uitzilopochtli",
    "Xicalango",
    "Xihuitl",
    "Xipilli",
    "Xiuhtecuhtli",
    "Xocotl",
    "Xochicuicatl",
    "Xochihuehuetl",
    "Xochipilli",
    "Xochiquetzal",
    "Xoco",
    "Xocomil",
    "Yaotl",
    "Yolihuani",
    "Yolotli",
    "Yolyamanitzin",
    "Zolin",
    "Zolinqui",
    "Zolinzontli",
]

surnames = [
    "(Amber Glow)",
    "(Amber Leaf)",
    "(Amber Twilight)",
    "(Amethyst Sky)",
    "(Ancient Ritual)",
    "(Ancient Stones)",
    "(Aurora's Grace)",
    "(Autumn Leaf)",
    "(Autumn's Breath)",
    "(Blossom Dance)",
    "(Blossom's Embrace)",
    "(Bountiful Harvest)",
    "(Bramble Thorn)",
    "(Celestial Beacon)",
    "(Celestial Dance)",
    "(Celestial Gateway)",
    "(Celestial Harmony)",
    "(Celestial Whispers)",
    "(Crescent Moon)",
    "(Crimson Twilight)",
    "(Dew-kissed Petals)",
    "(Divine Flame)",
    "(Dreamer's Dream)",
    "(Dreamer's Haven)",
    "(Dreamer's Refuge)",
    "(Dreamweaver)",
    "(Druid's Blessing)",
    "(Earth's Child)",
    "(Earthbound Wanderer)",
    "(Echoing Whispers)",
    "(Ember Glow)",
    "(Emerald Glade)",
    "(Emerald Oasis)",
    "(Emerald Whisper)",
    "(Enchanted Arboretum)",
    "(Enchanted Cascade)",
    "(Enchanted Ember)",
    "(Enchanted Forest)",
    "(Enchanted Grove)",
    "(Enchanted Sanctuary)",
    "(Enchanted Thicket)",
    "(Enchanted Waterfall)",
    "(Enigmatic Echo)",
    "(Eternal Bliss)",
    "(Eternal Journey)",
    "(Eternal Solitude)",
    "(Eternal Twilight)",
    "(Ethereal Mist)",
    "(Evergreen Refuge)",
    "(Evergreen Sentinel)",
    "(Everlasting Meadow)",
    "(Fairy's Kiss)",
    "(Fairy's Lullaby)",
    "(Fairy's Whim)",
    "(Fern Whisperer)",
    "(Firefly Glade)",
    "(Frostbitten Path)",
    "(Frostfire Valley)",
    "(Frostwind Vale)",
    "(Frozen Forest)",
    "(Frozen Lake)",
    "(Gentle Rain)",
    "(Golden Harvest)",
    "(Golden Sunset)",
    "(Hallowed Ground)",
    "(Hallowed Sanctuary)",
    "(Harmony Song)",
    "(Harmony's Echo)",
    "(Harmony's Song)",
    "(Harvest Moon)",
    "(Hidden Path)",
    "(Jade Serpent)",
    "(Journey's Beginning)",
    "(Journey's End)",
    "(Lily Pad's Secret)",
    "(Lorekeeper)",
    "(Luminous Echo)",
    "(Luminous Glow)",
    "(Luminous Oasis)",
    "(Lunar Enchantment)",
    "(Majestic Forest)",
    "(Majestic Peaks)",
    "(Meadowlark's Call)",
    "(Mistweaver)",
    "(Moonbeam Glow)",
    "(Moonlit Enchantment)",
    "(Moonlit Meadow)",
    "(Moonlit Oasis)",
    "(Moonlit Reflection)",
    "(Moonlit Serenade)",
    "(Moonstone Path)",
    "(Mossy Glade)",
    "(Mossy Grotto)",
    "(Mossy Hollow)",
    "(Mossy Pathway)",
    "(Mossy Stones)",
    "(Mountain's Majesty)",
    "(Mystic Caverns)",
    "(Mystic Dreamer)",
    "(Mystic Echoes)",
    "(Mystic Journey)",
    "(Mystic Runes)",
    "(Mystic Wanderer)",
    "(Mystical Nomad)",
    "(Nature's Embrace)",
    "(Nightfall Hymn)",
    "(Nightshade Grove)",
    "(Nightshade Moon)",
    "(Nightshade Serenade)",
    "(Nightshade Whisper)",
    "(Oakheart)",
    "(Rainbow Serenade)",
    "(Rainbow's Promise)",
    "(Raindrop Melody)",
    "(Raindrop Serenade)",
    "(Raven's Cry)",
    "(Raven's Feather)",
    "(Raven's Flight)",
    "(Raven's Haven)",
    "(Raven's Wing)",
    "(River Serenade)",
    "(River of Serenity)",
    "(River's Reflection)",
    "(River's Song)",
    "(Rune Carver)",
    "(Sacred Haven)",
    "(Sacred Oak)",
    "(Sacred Spring)",
    "(Sacred Whispers)",
    "(Sage's Haven)",
    "(Sage's Path)",
    "(Sage's Wisdom)",
    "(Sagebrush Tales)",
    "(Secret Grove)",
    "(Secret Whispers)",
    "(Serenity's Call)",
    "(Shimmering Cascade)",
    "(Silent Forest)",
    "(Silent Watcher)",
    "(Silver Mist)",
    "(Solar Eclipse)",
    "(Solar Flare)",
    "(Solar Radiance)",
    "(Solar Serenade)",
    "(Solitary Seeker)",
    "(Song of the River)",
    "(Soul Seeker)",
    "(Soul's Journey)",
    "(Soul's Sanctuary)",
    "(Spirit Seeker)",
    "(Spirit Weaver)",
    "(Spiritual Resonance)",
    "(Stardust Haven)",
    "(Stardust Symphony)",
    "(Starlit Haven)",
    "(Starlit Sky)",
    "(Starry Constellation)",
    "(Starry Nightfall)",
    "(Storm's Fury)",
    "(Stormborn)",
    "(Sun-kissed Valley)",
    "(Sunbeam's Embrace)",
    "(Thistle Thorne)",
    "(Thorned Bramble)",
    "(Thorned Briar)",
    "(Thorned Rose)",
    "(Thorned Vine)",
    "(Thunder's Echo)",
    "(Thunder's Fury)",
    "(Thunderous Roar)",
    "(Thunderstorm)",
    "(Twilight Reflections)",
    "(Twilight Shadows)",
    "(Twilight Veil)",
    "(Twilight Whispers)",
    "(Wandering Breeze)",
    "(Wandering Spirit)",
    "(Wandering Willow)",
    "(Whirling Vortex)",
    "(Whispered Incantation)",
    "(Whispering Brook)",
    "(Whispering Echoes)",
    "(Whispering Embers)",
    "(Whispering Hollow)",
    "(Whispering Willow)",
    "(Whispering Woods)",
    "(Whispering Zephyr)",
    "(Wildflower Fields)",
    "(Wildwood Wanderer)",
    "(Willow Whisper)",
    "(Wisp of Twilight)",
    "(Woodland Guardian)",
    "(Zephyr's Breath)",
    "(Zephyr's Caress)",
    "(Zephyr's Touch)",
]
