female_prefix = [
    "ard",
    "bert",
    "bold",
    "brand",
    "dolf",
    "fred",
    "frid",
    "gard",
    "hardt",
    "helm",
    "her",
    "mar",
    "olf",
    "ric",
    "rich",
    "rik",
    "wald",
    "ward",
    "win",
]

female_suffix = [
    "a",
    "burg",
    "dís",
    "fred",
    "gard",
    "gund",
    "hild",
    "hildis",
    "lind",
    "run",
    "sind",
    "svein",
    "thild",
    "trud",
    "unn",
    "vild",
    "vind",
    "wig",
]

male_prefix = [
    "ald",
    "alf",
    "am",
    "arn",
    "ber",
    "brand",
    "dank",
    "ed",
    "ein",
    "ern",
    "frid",
    "ger",
    "gott",
    "grim",
    "gun",
    "hart",
    "hein",
    "helm",
    "her",
    "hild",
    "hugo",
    "karl",
    "leif",
    "loth",
    "nor",
    "os",
    "osw",
    "rad",
    "rich",
    "roth",
    "sig",
    "thor",
    "ulf",
    "wal",
    "win",
    "wolf",
]

male_suffix = [
    "ard",
    "bert",
    "bold",
    "brand",
    "dolf",
    "fred",
    "frid",
    "gard",
    "hardt",
    "helm",
    "her",
    "mar",
    "olf",
    "ric",
    "rich",
    "rik",
    "wald",
    "ward",
    "win",
]

surname_prefix = [
    "ber",
    "dorn",
    "eis",
    "frey",
    "gau",
    "hart",
    "johann",
    "kraus",
    "lud",
    "meier",
    "nacht",
    "ott",
    "pfeffer",
    "rhein",
    "schwarz",
    "stein",
    "thor",
    "ulrich",
    "vogel",
    "wagner",
    "zeis",
]

surname_suffix = [
    "bach",
    "berg",
    "brand",
    "feld",
    "fels",
    "fisch",
    "grimm",
    "hammer",
    "hoff",
    "kamp",
    "müller",
    "schmidt",
    "schneider",
    "stern",
    "wald",
    "weber",
    "wolf",
    "wulf",
    "zimmer",
]

female_names = [
    "Adalheid",
    "Agatha",
    "Alberada",
    "Aldegund",
    "Aldgund",
    "Alfriede",
    "Alheidis",
    "Alruna",
    "Amalberga",
    "Amalia",
    "Ansgard",
    "Ansgunde",
    "Astrid",
    "Berta",
    "Bertha",
    "Brigitta",
    "Brunhild",
    "Dagmar",
    "Eberhild",
    "Edda",
    "Edelgard",
    "Edeltraud",
    "Edith",
    "Eduarda",
    "Eilika",
    "Elisabeth",
    "Else",
    "Emmaline",
    "Engelberga",
    "Ermentrud",
    "Erna",
    "Ethelinde",
    "Friedegund",
    "Friederike",
    "Friedhild",
    "Friedlinde",
    "Gabriele",
    "Gebharda",
    "Gerburg",
    "Gerda",
    "Gerhild",
    "Gerlind",
    "Gertrud",
    "Gisela",
    "Gislinde",
    "Godelind",
    "Gotelind",
    "Grimhild",
    "Gudrun",
    "Hedwig",
    "Heidrun",
    "Heilwig",
    "Helena",
    "Helgard",
    "Hella",
    "Henrike",
    "Hilde",
    "Hildegard",
    "Hiltrud",
    "Ilse",
    "Imma",
    "Immelind",
    "Inge",
    "Ingeborg",
    "Ingrid",
    "Irmgard",
    "Irmingard",
    "Isolde",
    "Johanna",
    "Karin",
    "Karoline",
    "Katharina",
    "Klara",
    "Klothilde",
    "Kriemhild",
    "Liesel",
    "Lieselotte",
    "Linda",
    "Liselotte",
    "Lothild",
    "Luise",
    "Magdalena",
    "Margarita",
    "Margot",
    "Marlene",
    "Matilda",
    "Mechthild",
    "Melisande",
    "Mona",
    "Oda",
    "Olga",
    "Ortrud",
    "Regina",
    "Ricarda",
    "Rita",
    "Rosalinde",
    "Roswitha",
    "Sabine",
    "Sibylle",
    "Siegrid",
    "Siglinde",
    "Sigrid",
    "Silke",
    "Solveig",
    "Sophie",
    "Swanhild",
    "Sylvia",
    "Theodora",
    "Theresia",
    "Ursula",
    "Walburga",
    "Waldtraud",
    "Wanda",
    "Wilfrieda",
    "Wilhelmina",
    "Winifred",
    "Yvonne",
    "Zelda",
]

male_names = [
    "Adalard",
    "Adalbert",
    "Adalhard",
    "Adalhelm",
    "Adalmar",
    "Adalric",
    "Adalwin",
    "Adalwolf",
    "Adelbert",
    "Adelhard",
    "Adelmar",
    "Adelulf",
    "Ademar",
    "Adolar",
    "Adolph",
    "Aldo",
    "Aldric",
    "Alfred",
    "Alwin",
    "Amalric",
    "Amelung",
    "Anselm",
    "Armin",
    "Arnulf",
    "Baldemar",
    "Balderich",
    "Baldo",
    "Baldric",
    "Balthasar",
    "Berenger",
    "Bernard",
    "Bernulf",
    "Berthold",
    "Bertram",
    "Bruno",
    "Conrad",
    "Dagobert",
    "Dietrich",
    "Eberhard",
    "Edwin",
    "Eginhard",
    "Eldric",
    "Emmerich",
    "Erhard",
    "Ermenrich",
    "Erwin",
    "Ferdinand",
    "Folker",
    "Folkmar",
    "Franz",
    "Frederick",
    "Friedrich",
    "Gebhard",
    "Gerard",
    "Gero",
    "Gerwin",
    "Giselbert",
    "Gisulf",
    "Gottfried",
    "Gunther",
    "Hagen",
    "Hanno",
    "Hartmann",
    "Heinrich",
    "Helmut",
    "Herbert",
    "Heribert",
    "Hermann",
    "Hildebrand",
    "Hubert",
    "Hugo",
    "Ingmar",
    "Ivo",
    "Karl",
    "Kaspar",
    "Konrad",
    "Lambert",
    "Lando",
    "Leopold",
    "Lothar",
    "Ludwig",
    "Magnus",
    "Markus",
    "Matthias",
    "Maximilian",
    "Norbert",
    "Odilo",
    "Odo",
    "Otto",
    "Pepin",
    "Rainer",
    "Reinhard",
    "Rolf",
    "Rudolf",
    "Siegfried",
    "Sigbert",
    "Sigmund",
    "Theobald",
    "Theodoric",
    "Ulrich",
    "Valentin",
    "Volkmar",
    "Waldo",
    "Walther",
    "Werner",
    "Wido",
    "Wilhelm",
    "Willibald",
    "Winfred",
    "Wolfgang",
    "Wulfric",
    "Zigmund",
]

surnames = [
    "Adler",
    "Albrecht",
    "Baumann",
    "Beck",
    "Becker",
    "Berger",
    "Bergmann",
    "Beyer",
    "Bischof",
    "Blau",
    "Brauer",
    "Braun",
    "Brinkmann",
    "Brückner",
    "Buchholz",
    "Busch",
    "Christ",
    "Dietrich",
    "Döring",
    "Eckert",
    "Ehrlich",
    "Eichler",
    "Enders",
    "Engel",
    "Ernst",
    "Fischer",
    "Franke",
    "Freitag",
    "Fröhlich",
    "Fröhner",
    "Geiger",
    "Gerlach",
    "Graf",
    "Gruber",
    "Günther",
    "Hahn",
    "Hartmann",
    "Hartwig",
    "Hauser",
    "Heinrich",
    "Heller",
    "Hermann",
    "Herrmann",
    "Heß",
    "Hirsch",
    "Hoffmann",
    "Hofmann",
    "Holz",
    "Huber",
    "Jung",
    "Kaiser",
    "Keller",
    "Kemper",
    "Kessler",
    "Kirsch",
    "Klein",
    "Koch",
    "Konrad",
    "Kramer",
    "Kraus",
    "Krause",
    "Krüger",
    "Köhler",
    "König",
    "Kühn",
    "Lang",
    "Lehmann",
    "Lenz",
    "Lindemann",
    "Lorenz",
    "Ludwig",
    "Maier",
    "Martin",
    "Maurer",
    "Mayer",
    "Meier",
    "Meyer",
    "Miller",
    "Morgenstern",
    "Moser",
    "Möller",
    "Müller",
    "Neumann",
    "Ott",
    "Peters",
    "Pfeiffer",
    "Pohl",
    "Rau",
    "Reich",
    "Reinhardt",
    "Renner",
    "Richter",
    "Ritter",
    "Roth",
    "Rudolph",
    "Sauer",
    "Schilling",
    "Schlüter",
    "Schmid",
    "Schmidt",
    "Schneider",
    "Scholz",
    "Schreiber",
    "Schreiner",
    "Schroeder",
    "Schubert",
    "Schulz",
    "Schumacher",
    "Schuster",
    "Schwarz",
    "Schäfer",
    "Seidel",
    "Seifert",
    "Simon",
    "Sommer",
    "Stark",
    "Steffens",
    "Stein",
    "Steiner",
    "Sturm",
    "Theis",
    "Thiel",
    "Thomas",
    "Vogel",
    "Vogt",
    "Voigt",
    "Wagner",
    "Walter",
    "Weber",
    "Weiss",
    "Weiß",
    "Werner",
    "Wiedemann",
    "Wiegand",
    "Wimmer",
    "Winter",
    "Wirth",
    "Wittmann",
    "Wolf",
    "Wolff",
    "Wunderlich",
    "Ziegler",
    "Zimmermann",
]

