female_names = [
    "Adelaide",
    "Adriana",
    "Amara",
    "Amaryllis",
    "Anastasia",
    "Arabella",
    "Ariadne",
    "Arianwen",
    "Astoria",
    "Aurelia",
    "Brielle",
    "Calliope",
    "Cassandra",
    "Celestia",
    "Cressida",
    "Dahlia",
    "Elara",
    "Eleanor",
    "Elowen",
    "Elysia",
    "Emmeline",
    "Evaine",
    "Evangeline",
    "Evelina",
    "Fiona",
    "Fiora",
    "Genevieve",
    "Ginevra",
    "Giselle",
    "Guinevere",
    "Gwendolyn",
    "Helena",
    "Helene",
    "Iliana",
    "Imelda",
    "Isabeau",
    "Isolde",
    "Jessamine",
    "Jocelyn",
    "Lavinia",
    "Lorelei",
    "Lyra",
    "Maelisande",
    "Marigold",
    "Melisande",
    "Mirella",
    "Morgana",
    "Morwenna",
    "Nerissa",
    "Octavia",
    "Ophelia",
    "Oriana",
    "Pandora",
    "Persephone",
    "Quintessa",
    "Ravenna",
    "Rosalind",
    "Rosamund",
    "Rowena",
    "Sabrina",
    "Selene",
    "Seraphina",
    "Seraphine",
    "Sylvana",
    "Tatiana",
    "Thalia",
    "Titania",
    "Ursula",
    "Vespera",
    "Viola",
    "Vivienne",
    "Wilhelmina",
    "Winifred",
    "Xanthe",
    "Yara",
    "Yvette",
    "Zephyrine",
]

male_names = [
    "Ambrose",
    "Arthur",
    "Balthazar",
    "Benedict",
    "Caius",
    "Cassius",
    "Cedric",
    "Dominic",
    "Dorian",
    "Edmund",
    "Edric",
    "Emeric",
    "Ezekiel",
    "Felix",
    "Finnian",
    "Frederick",
    "Galahad",
    "Gareth",
    "Gawain",
    "Gerard",
    "Gideon",
    "Hadrian",
    "Harold",
    "Hector",
    "Horatio",
    "Ignatius",
    "Jareth",
    "Jasper",
    "Jeremiah",
    "Kieran",
    "Lancelot",
    "Lazarus",
    "Leander",
    "Leopold",
    "Luther",
    "Lysander",
    "Magnus",
    "Maximilian",
    "Merrick",
    "Nathaniel",
    "Oberon",
    "Orlando",
    "Oswald",
    "Percival",
    "Peregrine",
    "Quentin",
    "Quirinus",
    "Raphael",
    "Reginald",
    "Roderick",
    "Sebastian",
    "Solomon",
    "Sylvester",
    "Thaddeus",
    "Theobald",
    "Theron",
    "Tristan",
    "Tristram",
    "Ulric",
    "Ulysses",
    "Uriah",
    "Valerian",
    "Vance",
    "Victor",
    "Wilfred",
    "Winston",
    "Xander",
    "Xavier",
    "Yale",
    "Yorick",
    "Zacharias",
    "Zephyr",
]

surname_prefix = [
    "Amber",
    "Black",
    "Blade",
    "Blaze",
    "Blood",
    "Bright",
    "Dark",
    "Dawn",
    "Dragon",
    "Dusk",
    "Fire",
    "Frost",
    "Golden",
    "Hawk",
    "Iron",
    "Mist",
    "Moon",
    "Night",
    "Oak",
    "Raven",
    "Shadow",
    "Silver",
    "Star",
    "Steel",
    "Stone",
    "Storm",
    "Swift",
    "Sword",
    "Thorn",
    "Thunder",
    "Valiant",
    "White",
    "Wind",
    "Winter",
    "Wolf",
]

surname_suffix = [
    "arrow",
    "bane",
    "bark",
    "beard",
    "blade",
    "blood",
    "breaker",
    "brook",
    "caster",
    "claw",
    "dusk",
    "eye",
    "fall",
    "fang",
    "field",
    "fire",
    "fist",
    "flame",
    "foot",
    "hawk",
    "heart",
    "helm",
    "leaf",
    "mantle",
    "mist",
    "moon",
    "raven",
    "rider",
    "scale",
    "shadow",
    "shard",
    "shield",
    "song",
    "spear",
    "steel",
    "stone",
    "storm",
    "strike",
    "sword",
    "thistle",
    "thorn",
    "thunder",
    "vale",
    "walker",
    "warden",
    "watch",
    "weaver",
    "wind",
    "wing",
    "wood",
]

surnames = [
    "Acker",
    "Adler",
    "Albrecht",
    "Angermann",
    "Arnold",
    "Auerbach",
    "Bauer",
    "Baumann",
    "Baumgartner",
    "Becker",
    "Berger",
    "Bergmann",
    "Beyer",
    "Beyerlein",
    "Biedermann",
    "Blume",
    "Bock",
    "Borchardt",
    "Brandt",
    "Braun",
    "Brinkmann",
    "Brunner",
    "Bucher",
    "Conrad",
    "Dietrich",
    "Dorn",
    "Drescher",
    "Eberhardt",
    "Ebert",
    "Eckert",
    "Eggert",
    "Eisenmann",
    "Engel",
    "Fink",
    "Fischer",
    "Fleischer",
    "Fleischmann",
    "Franke",
    "Freitag",
    "Frey",
    "Friedrich",
    "Fuchs",
    "Gebhardt",
    "Geier",
    "Gerber",
    "Gottschalk",
    "Graf",
    "Groß",
    "Gruber",
    "Gräf",
    "Gärtner",
    "Haas",
    "Hagen",
    "Hahn",
    "Hammer",
    "Hartmann",
    "Hartwig",
    "Haupt",
    "Hecht",
    "Heimann",
    "Hein",
    "Heinrich",
    "Held",
    "Heller",
    "Hermann",
    "Herzog",
    "Hirsch",
    "Hoffmann",
    "Holländer",
    "Holzer",
    "Holzknecht",
    "Hoppe",
    "Huber",
    "Hubert",
    "Höfer",
    "Jacob",
    "Jansen",
    "Jung",
    "Jäger",
    "Jänicke",
    "Kaiser",
    "Kappler",
    "Kaufmann",
    "Keller",
    "Kiefer",
    "Kirsch",
    "Klein",
    "Knecht",
    "Koch",
    "Kopp",
    "Krause",
    "Krauß",
    "Krebs",
    "Kretschmann",
    "Krug",
    "Krüger",
    "Kuhn",
    "Kunz",
    "Kurz",
    "Köhler",
    "König",
    "Kühn",
    "Landgraf",
    "Lang",
    "Lange",
    "Langenberg",
    "Lechner",
    "Lehmann",
    "Leibnitz",
    "Lindemann",
    "Lorenz",
    "Ludwig",
    "Maier",
    "Mann",
    "Martin",
    "Maurer",
    "Mayer",
    "Meier",
    "Meister",
    "Merz",
    "Messer",
    "Meyer",
    "März",
    "Müller",
    "Neubauer",
    "Neumann",
    "Nussbaum",
    "Pfeiffer",
    "Pohl",
    "Popp",
    "Rapp",
    "Reinhardt",
    "Reiter",
    "Richter",
    "Riedel",
    "Ritter",
    "Rohde",
    "Roth",
    "Rothmann",
    "Sachs",
    "Sauer",
    "Schaller",
    "Schell",
    "Schick",
    "Schindler",
    "Schmid",
    "Schmidt",
    "Schmitz",
    "Schneider",
    "Scholz",
    "Schott",
    "Schreiber",
    "Schreiner",
    "Schubert",
    "Schulz",
    "Schumacher",
    "Schuster",
    "Schwab",
    "Schwarz",
    "Schweitzer",
    "Schäfer",
    "Seidel",
    "Seligmann",
    "Simon",
    "Sommer",
    "Sonnemann",
    "Sperling",
    "Stein",
    "Steiner",
    "Stern",
    "Stolz",
    "Sturm",
    "Taubert",
    "Thiel",
    "Thiele",
    "Thomas",
    "Ullmann",
    "Ulrich",
    "Unger",
    "Vogel",
    "Vogt",
    "Voigt",
    "Wagner",
    "Walter",
    "Walther",
    "Weber",
    "Weiß",
    "Wendt",
    "Werner",
    "Wieland",
    "Winkler",
    "Winter",
    "Wolf",
    "Wolff",
    "Zahn",
    "Zander",
    "Ziegler",
    "Zimmermann",
    "Zink",
    "Zoller",
    "Zorn",
    "Zuber",
    "Zumwinkel",
]
