female_prefix = [
    "ai",
    "an",
    "bai",
    "bing",
    "cui",
    "dan",
    "fang",
    "fen",
    "guan",
    "hong",
    "hua",
    "jing",
    "lan",
    "li",
    "lu",
    "mei",
    "ming",
    "na",
    "ning",
    "ping",
    "qi",
    "qian",
    "rong",
    "shuang",
    "ting",
    "wan",
    "xi",
    "xia",
    "xiang",
    "yan",
    "ying",
    "yun",
    "zhen",
    "zhu",
]

female_suffix = [
    "hua",
    "ying",
    "yun",
    "lan",
    "mei",
    "xiu",
    "jiao",
    "li",
    "fang",
    "ping",
    "rong",
    "xue",
    "hua",
    "zhen",
    "ying",
    "xiang",
    "ting",
    "na",
    "ning",
    "yun",
    "fang",
    "yan",
    "ying",
    "jing",
    "hua",
    "ying",
    "xin",
    "lian",
    "xi",
    "xia",
    "yu",
    "jing",
    "hua",
]

male_prefix = [
    "bei",
    "bo",
    "cai",
    "chen",
    "chi",
    "chong",
    "da",
    "ding",
    "dong",
    "feng",
    "fu",
    "gong",
    "gu",
    "han",
    "hong",
    "hu",
    "ji",
    "jian",
    "jin",
    "ju",
    "jun",
    "kai",
    "li",
    "lin",
    "ming",
    "nan",
    "ning",
    "peng",
    "qing",
    "quan",
    "ren",
    "rong",
    "sheng",
    "shi",
    "shu",
    "tao",
    "tian",
    "wei",
    "wen",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xin",
    "xing",
    "xiong",
    "yang",
    "yi",
    "yong",
    "yu",
    "yuan",
    "yue",
    "yun",
    "zhan",
    "zhen",
    "zheng",
    "zhong",
    "zhou",
    "zhu",
    "zhuo",
]

male_suffix = [
    "bin",
    "bo",
    "cheng",
    "chun",
    "cong",
    "da",
    "dan",
    "deng",
    "dong",
    "feng",
    "gang",
    "guo",
    "hao",
    "he",
    "heng",
    "hong",
    "hua",
    "huang",
    "jian",
    "jing",
    "jun",
    "kai",
    "li",
    "liang",
    "lin",
    "ming",
    "nan",
    "ning",
    "peng",
    "qiang",
    "qing",
    "quan",
    "ren",
    "rong",
    "sheng",
    "shi",
    "shuai",
    "song",
    "tao",
    "ting",
    "wei",
    "wen",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xin",
    "xing",
    "xiong",
    "yang",
    "yi",
    "yong",
    "yu",
    "yuan",
    "yue",
    "yun",
    "zhan",
    "zhen",
    "zheng",
    "zhong",
    "zhou",
    "zhu",
    "zhuo",
]

surname_prefix = [
    "bai",
    "cao",
    "chen",
    "dai",
    "ding",
    "du",
    "fan",
    "fu",
    "gan",
    "gu",
    "guo",
    "han",
    "hu",
    "hua",
    "huang",
    "ji",
    "jiang",
    "jin",
    "kong",
    "li",
    "lian",
    "lin",
    "liu",
    "lu",
    "lv",
    "ma",
    "meng",
    "nan",
    "ni",
    "pan",
    "peng",
    "qi",
    "qian",
    "qin",
    "qiu",
    "shao",
    "shen",
    "shi",
    "song",
    "su",
    "sun",
    "tan",
    "tang",
    "wan",
    "wang",
    "wei",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xiao",
    "xie",
    "xiong",
    "xu",
    "yang",
    "yi",
    "yin",
    "yuan",
    "zeng",
    "zhang",
    "zhao",
    "zhen",
    "zheng",
    "zhou",
    "zhu",
    "zhao",
]

surname_suffix = [
    "an",
    "ang",
    "ao",
    "bei",
    "bin",
    "bo",
    "chan",
    "chang",
    "cheng",
    "chong",
    "chu",
    "chuan",
    "chun",
    "cui",
    "dan",
    "dang",
    "deng",
    "dong",
    "fan",
    "fang",
    "fen",
    "feng",
    "fu",
    "gan",
    "gang",
    "gu",
    "guan",
    "gui",
    "hao",
    "he",
    "heng",
    "hong",
    "hou",
    "hu",
    "huang",
    "hui",
    "ji",
    "jian",
    "jiang",
    "jiao",
    "jin",
    "jing",
    "kang",
    "ke",
    "kong",
    "kuai",
    "kun",
    "lan",
    "li",
    "lian",
    "liang",
    "lin",
    "ling",
    "long",
    "lu",
    "luan",
    "lun",
    "mei",
    "min",
    "ming",
    "mou",
    "nan",
    "ning",
    "nong",
    "nuan",
    "peng",
    "qi",
    "qian",
    "qiang",
    "qin",
    "qing",
    "qiong",
    "quan",
    "rui",
    "run",
    "shan",
    "sheng",
    "shi",
    "shou",
    "song",
    "su",
    "sun",
    "tai",
    "tang",
    "ting",
    "tong",
    "wei",
    "wen",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xiao",
    "xin",
    "xing",
    "xiong",
    "xu",
    "yang",
    "yan",
    "yang",
    "yin",
    "ying",
    "yu",
    "yuan",
    "yun",
    "zhan",
    "zhang",
    "zhao",
    "zhen",
    "zheng",
    "zhi",
    "zhong",
    "zhou",
    "zhu",
    "zong",
]

female_names = [
    "Ai",
    "An",
    "Ao",
    "Bai",
    "Bi",
    "Bing",
    "Bo",
    "Cai",
    "Cen",
    "Ci",
    "Dai",
    "Dan",
    "Ding",
    "Dong",
    "E",
    "Fang",
    "Fangfang",
    "Fei",
    "Fen",
    "Fu",
    "Gao",
    "Gui",
    "Han",
    "Hong",
    "Hongli",
    "Hongmei",
    "Hongyun",
    "Hu",
    "Hua",
    "Hui",
    "Huifang",
    "Huihui",
    "Huiling",
    "Ji",
    "Jia",
    "Jiajia",
    "Jian",
    "Jiang",
    "Jiao",
    "Jie",
    "Jin",
    "Jing",
    "Jingjing",
    "Jingyun",
    "Ju",
    "Juan",
    "Jun",
    "Kai",
    "Lan",
    "Li",
    "Lian",
    "Liang",
    "Lihua",
    "Lili",
    "Lin",
    "Lina",
    "Ling",
    "Lingling",
    "Liu",
    "Liuying",
    "Liya",
    "Lu",
    "Luan",
    "Lü",
    "Man",
    "Mei",
    "Meihua",
    "Meimei",
    "Min",
    "Ming",
    "Minmin",
    "Mu",
    "Nan",
    "Ning",
    "Nu",
    "Pang",
    "Ping",
    "Pingping",
    "Qi",
    "Qian",
    "Qiang",
    "Qianqian",
    "Qiaoling",
    "Qin",
    "Qing",
    "Qingqing",
    "Qingyuan",
    "Qiong",
    "Qiqi",
    "Qiu",
    "Ran",
    "Rong",
    "Rongrong",
    "Ru",
    "Ruo",
    "Shan",
    "Shang",
    "Shanshan",
    "Shao",
    "Shi",
    "Shu",
    "Shuang",
    "Si",
    "Su",
    "Tang",
    "Tiantian",
    "Ting",
    "Tingting",
    "Wan",
    "Wei",
    "Weili",
    "Wen",
    "Wenjuan",
    "Wenqian",
    "Wenwen",
    "Wu",
    "Xi",
    "Xia",
    "Xiang",
    "Xiao",
    "Xiaofeng",
    "Xiaohong",
    "Xiaohua",
    "Xiaojuan",
    "Xiaoling",
    "Xiaomei",
    "Xiaoqin",
    "Xiaowei",
    "Xiaoxia",
    "Xiaoxiao",
    "Xiaoxue",
    "Xiaoyan",
    "Xiaoying",
    "Xin",
    "Xinran",
    "Xinyi",
    "Xiu",
    "Xiulan",
    "Xiuying",
    "Xu",
    "Xuan",
    "Xuanxuan",
    "Xue",
    "Yajie",
    "Yan",
    "Yanfen",
    "Yang",
    "Yanhua",
    "Yanli",
    "Yao",
    "Ye",
    "Yi",
    "Ying",
    "Yinghua",
    "Yingying",
    "Yingzi",
    "Yiyi",
    "Yong",
    "Yonghong",
    "You",
    "Yu",
    "Yuan",
    "Yuanli",
    "Yuanyuan",
    "Yue",
    "Yumei",
    "Yun",
    "Yuqing",
    "Zeng",
    "Zhan",
    "Zhang",
    "Zhao",
    "Zhen",
    "Zheng",
    "Zhenzhen",
    "Zhi",
    "Zhong",
    "Zhou",
    "Zhu",
    "Zhuang",
    "Zhuo",
    "Zi",
    "Zong",
    "Zuo",
]

male_names = [
    "Bao",
    "Bing",
    "Bo",
    "Cai",
    "Cao",
    "Cen",
    "Chai",
    "Chao",
    "Chen",
    "Cheng",
    "Chu",
    "Cui",
    "Dai",
    "Dan",
    "Deng",
    "Ding",
    "Dong",
    "Du",
    "Duan",
    "Fan",
    "Fang",
    "Feng",
    "Fu",
    "Gan",
    "Gao",
    "Ge",
    "Gong",
    "Gu",
    "Guan",
    "Gui",
    "Guo",
    "Han",
    "Hao",
    "He",
    "Heng",
    "Hong",
    "Hou",
    "Hu",
    "Hua",
    "Huang",
    "Hui",
    "Ji",
    "Jian",
    "Jiang",
    "Jiao",
    "Jin",
    "Jing",
    "Jiu",
    "Ju",
    "Jun",
    "Kang",
    "Ke",
    "Kong",
    "Lai",
    "Lei",
    "Li",
    "Lian",
    "Liang",
    "Liao",
    "Lin",
    "Ling",
    "Liu",
    "Long",
    "Lu",
    "Luan",
    "Lü",
    "Ma",
    "Mai",
    "Mao",
    "Mei",
    "Meng",
    "Mi",
    "Miao",
    "Ming",
    "Mo",
    "Nan",
    "Nian",
    "Ning",
    "Nuo",
    "Pai",
    "Pan",
    "Ping",
    "Po",
    "Pu",
    "Qi",
    "Qian",
    "Qiang",
    "Qin",
    "Qing",
    "Qiu",
    "Qu",
    "Quan",
    "Ren",
    "Rong",
    "Ru",
    "Rui",
    "Run",
    "Sai",
    "Shan",
    "Shang",
    "Shao",
    "Shen",
    "Sheng",
    "Shi",
    "Shou",
    "Shu",
    "Si",
    "Song",
    "Su",
    "Sui",
    "Sun",
    "Tai",
    "Tang",
    "Tao",
    "Tian",
    "Tong",
    "Tu",
    "Wan",
    "Wang",
    "Wei",
    "Wen",
    "Wu",
    "Xi",
    "Xian",
    "Xiang",
    "Xiao",
    "Xin",
    "Xing",
    "Xiu",
    "Xu",
    "Xuan",
    "Xue",
    "Yang",
    "Yao",
    "Ye",
    "Yi",
    "Yin",
    "Ying",
    "Yong",
    "You",
    "Yu",
    "Yuan",
    "Yue",
    "Yun",
    "Zeng",
    "Zhang",
    "Zhao",
    "Zhen",
    "Zheng",
    "Zhi",
    "Zhong",
    "Zhou",
    "Zhu",
    "Zhuan",
    "Zhuo",
    "Zi",
    "Zong",
    "Zu",
]

surnames = [
    "Bai",
    "Bo",
    "Cao",
    "Chen",
    "Chi",
    "Chu",
    "Cui",
    "Dai",
    "Ding",
    "Dong",
    "Du",
    "Duan",
    "Fan",
    "Fang",
    "Feng",
    "Fu",
    "Gao",
    "Ge",
    "Gong",
    "Gu",
    "Guan",
    "Gui",
    "Han",
    "Hao",
    "He",
    "Hong",
    "Hu",
    "Hua",
    "Huang",
    "Hui",
    "Ji",
    "Jian",
    "Jiang",
    "Jiao",
    "Jin",
    "Jing",
    "Jiu",
    "Kang",
    "Ke",
    "Kong",
    "Kuang",
    "Lei",
    "Li",
    "Lian",
    "Liang",
    "Lin",
    "Ling",
    "Liu",
    "Long",
    "Lu",
    "Luan",
    "Lü",
    "Ma",
    "Mai",
    "Meng",
    "Mi",
    "Miao",
    "Ming",
    "Mo",
    "Mu",
    "Nan",
    "Ni",
    "Ning",
    "Pan",
    "Peng",
    "Ping",
    "Pu",
    "Qian",
    "Qiao",
    "Qing",
    "Qiu",
    "Qu",
    "Ren",
    "Rong",
    "Ru",
    "Shan",
    "Shang",
    "Shen",
    "Shi",
    "Shu",
    "Si",
    "Song",
    "Sun",
    "Suo",
    "Tai",
    "Tang",
    "Tao",
    "Tian",
    "Tong",
    "Wang",
    "Wei",
    "Wen",
    "Wu",
    "Xi",
    "Xia",
    "Xiao",
    "Xin",
    "Xing",
    "Xiong",
    "Xiu",
    "Xu",
    "Xue",
    "Yan",
    "Yang",
    "Yao",
    "Ye",
    "Yi",
    "Yin",
    "Ying",
    "You",
    "Yu",
    "Yuan",
    "Yue",
    "Yun",
    "Zeng",
    "Zhang",
    "Zhao",
    "Zhen",
    "Zheng",
    "Zhi",
    "Zhong",
    "Zhou",
    "Zhu",
    "Zhuang",
    "Zi",
    "Zong",
    "Zou",
]
